@@ -1,27 +1,13 @@
+/*
+ * SPDX-License-Identifier: MIT
+ *
+ * Copyright (C) 2010-2019 EfficiOS Inc. and Linux Foundation
+ */
+
 #ifndef BABELTRACE2_GRAPH_MESSAGE_ITERATOR_CLASS_H
 #define BABELTRACE2_GRAPH_MESSAGE_ITERATOR_CLASS_H
 
-/*
- * Copyright (c) 2019 EfficiOS Inc.
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
+/* IWYU pragma: private, include <babeltrace2/babeltrace.h> */
 
 #ifndef __BT_IN_BABELTRACE_H
 # error "Please include <babeltrace2/babeltrace.h> instead."
@@ -31,7 +17,6 @@
 extern "C" {
 #endif
 
-
 /*!
 @defgroup api-msg-iter-cls Message iterator class
 @ingroup api-comp-cls-dev
@@ -47,15 +32,15 @@ A <strong><em>message iterator class</em></strong> is the class of a
 \bt_cp_src_comp_cls and \bt_p_flt_comp_cls contain a message iterator
 class. For such a component class, its message iterator class is the
 class of any message iterator created for any \bt_oport of the
-component class's instances (\bt_p_comp).
+instances of the component class (\bt_p_comp).
 
 Therefore, the only thing you can do with a message iterator class is to
 pass it to bt_component_class_source_create() or
-bt_component_class_filter_create() to set it as the created component
-class's message iterator class.
+bt_component_class_filter_create() to set it as the
+message iterator class of the created component class.
 
-A message iterator class has <em>methods</em>. This module essentially
-offers:
+A message iterator class has <em>methods</em>. This API
+essentially offers:
 
 - Message iterator class method type definitions.
 
@@ -66,9 +51,9 @@ offers:
 
 A message iterator class method is a user function. All message iterator
 class methods operate on an instance (a \bt_msg_iter). The type of the
-method's first parameter is #bt_self_message_iterator. This is similar
-to an instance method in Python (where the instance object name is
-generally <code>self</code>) or a member function in C++ (where the
+first parameter of the method is #bt_self_message_iterator. This is
+similar to an instance method in Python (where the instance object name
+is generally <code>self</code>) or a member function in C++ (where the
 instance pointer is named <code>this</code>), for example.
 
 See \ref api-msg-iter-cls-methods "Methods" to learn more about the
@@ -86,9 +71,9 @@ postcondition.
 The type of a message iterator class is #bt_message_iterator_class.
 
 Create a message iterator class with bt_message_iterator_class_create().
-When you call this function, you must pass the message iterator
-class's mandatory
-\link api-msg-iter-cls-meth-next "next" method\endlink.
+When you call this function, you must pass the mandatory
+\link api-msg-iter-cls-meth-next "next" method\endlink of the
+message iterator class.
 
 <h1>\anchor api-msg-iter-cls-methods Methods</h1>
 
@@ -153,8 +138,8 @@ The available message iterator class methods to implement are:
 
     The message iterator of a \bt_flt_comp will typically consider
     the beginning seeking capability of its own upstream message
-    iterator(s) (with bt_message_iterator_can_seek_beginning()) in this
-    method's implementation.
+    iterator(s) (with bt_message_iterator_can_seek_beginning()) in the
+    implementation of this method.
 
     If you need to block the thread to compute whether or not your
     message iterator can seek its beginning, you can instead report to
@@ -171,7 +156,7 @@ The available message iterator class methods to implement are:
   </dt>
   <dd>
     Called to check whether or not your \bt_msg_iter can currently
-    seek a message occuring at or after a specific time given in
+    seek a message occurring at or after a specific time given in
     nanoseconds from its
     \ref api-tir-clock-cls-origin "clock class origin".
 
@@ -181,21 +166,21 @@ The available message iterator class methods to implement are:
     Within this method, your receive the specific time to seek as the
     \bt_p{ns_from_origin} parameter. You don't receive any
     \bt_clock_cls: the method operates at the nanosecond from some
-    origin level and it is left to the implementation to decide whether
+    origin level and it's left to the implementation to decide whether
     or not the message iterator can seek this point in time.
 
     If you don't implement this method, then, if you implement the
     \ref api-msg-iter-cls-meth-seek-ns "seek ns from origin" method, the
     library assumes that your message iterator can always seek any
-    message occuring at or after any time.
+    message occurring at or after any time.
 
     The message iterator of a \bt_flt_comp will typically consider
     the time seeking capability of its own upstream message
     iterator(s) (with bt_message_iterator_can_seek_ns_from_origin()) in
-    this method's implementation.
+    the implementation of this method.
 
     If you need to block the thread to compute whether or not your
-    message iterator can seek a message occuring at or after a given
+    message iterator can seek a message occurring at or after a given
     time, you can instead report to try again later to the caller by
     returning
     #BT_MESSAGE_ITERATOR_CLASS_CAN_SEEK_NS_FROM_ORIGIN_METHOD_STATUS_AGAIN.
@@ -213,16 +198,16 @@ The available message iterator class methods to implement are:
     destroy/free/finalize any user data you have (retrieved with
     bt_self_message_iterator_get_data()).
 
-    The \bt_name library does not specify exactly when this method is
+    The \bt_name library doesn't specify exactly when this method is
     called, but guarantees that it's called before the message iterator
     is destroyed.
 
     The library guarantees that all message iterators are destroyed
     before their component is destroyed.
 
-    This method is \em not called if the message iterator's
-    \ref api-msg-iter-cls-meth-init "initialization method"
-    previously returned an error status code.
+    This method is \em not called if the
+    \ref api-msg-iter-cls-meth-init "initialization method" of the
+    message iterator previously returned an error status code.
 
     Set this optional method with
     bt_message_iterator_class_set_finalize_method().
@@ -237,7 +222,7 @@ The available message iterator class methods to implement are:
     or bt_message_iterator_create_from_sink_component() to initialize
     your \bt_msg_iter.
 
-    Within this method, you can access your \bt_comp's user data
+    Within this method, you can access the user data of your \bt_comp
     by first borrowing it with
     bt_self_message_iterator_borrow_component() and then using
     bt_self_component_get_data().
@@ -246,28 +231,29 @@ The available message iterator class methods to implement are:
     typically where you create an upstream \bt_msg_iter
     with bt_message_iterator_create_from_message_iterator().
 
-    You can create user data and set it as the \bt_self_msg_iter's user
-    data with bt_self_message_iterator_set_data().
+    You can create user data and set it as the user data of the
+    \bt_self_msg_iter with bt_self_message_iterator_set_data().
 
     If you return #BT_MESSAGE_ITERATOR_CLASS_INITIALIZE_METHOD_STATUS_OK
-    from this method, then your message iterator's
-    \ref api-msg-iter-cls-meth-fini "finalization method" will be
-    called, if it exists, when your message iterator is finalized.
+    from this method, then the
+    \ref api-msg-iter-cls-meth-fini "finalization method" of your
+    message iterator will be called, if it exists, when your message
+    iterator is finalized.
 
     This method receives a message iterator configuration object
     (#bt_self_message_iterator_configuration type). As of
     \bt_name_version_min_maj, you can use
     bt_self_message_iterator_configuration_set_can_seek_forward()
-    during, and only during, this method's execution to set whether or
-    not your message iterator can <em>seek forward</em>.
+    during, and only during, the execution of this method to set whether
+    or not your message iterator can <em>seek forward</em>.
 
     For a message iterator to be able to seek forward, all the \bt_p_msg
     of its message sequence must have some \bt_cs.
     bt_message_iterator_seek_ns_from_origin() uses this configuration
     option and the beginning seeking capability of a message iterator
     (bt_message_iterator_can_seek_beginning())
-    to make it seek a message occuring at or after a specific time even
-    when the message iterator does not implement the
+    to make it seek a message occurring at or after a specific time even
+    when the message iterator doesn't implement the
     \ref api-msg-iter-cls-meth-seek-ns "seek ns from origin" method.
 
     Set this optional method with
@@ -286,7 +272,7 @@ The available message iterator class methods to implement are:
     Within this method, you receive:
 
     - An array of \bt_p_msg to fill (\bt_p{messages} parameter)
-      with your message iterator's next messages, if any.
+      with the next messages of your message iterator, if any.
 
       Note that this array needs its own message
       \ref api-fund-shared-object "references". In other
@@ -317,22 +303,22 @@ The available message iterator class methods to implement are:
     This method typically:
 
     <dl>
-      <dt>For a \bt_src_comp's message iterator</dt>
+      <dt>For the message iterator of a \bt_src_comp</dt>
       <dd>
         Creates brand new \bt_p_msg to represent one or more input
         traces.
       </dd>
 
-      <dt>For a \bt_flt_comp's message iterator</dt>
+      <dt>For the message iterator of a \bt_flt_comp</dt>
       <dd>
         Gets \em one message batch from one (or more) upstream
         \bt_msg_iter and filters them.
       </dd>
     </dl>
 
-    For a source component's message iterator, you are free to create
-    as many as \bt_p{capacity} messages. For a filter component's
-    message iterator, you are free to get more than one batch of
+    For the message iterator of a source component, you're free to
+    create as many as \bt_p{capacity} messages. For the message iterator
+    of a filter component, you're free to get more than one batch of
     messages from upstream message iterators if needed. However, in both
     cases, keep in mind that the \bt_name project recommends that this
     method executes fast enough so as not to block an interactive
@@ -352,8 +338,8 @@ The available message iterator class methods to implement are:
     When you return this status code, you must \em not put any message
     into the message array.
 
-    If your message iterator's iteration process is done (you have no
-    more messages to emit), then return
+    If the iteration process of your message iterator is done (you have
+    no more messages to emit), then return
     #BT_MESSAGE_ITERATOR_CLASS_NEXT_METHOD_STATUS_END. When you return
     this status code, you must \em not put any message into the message
     array.
@@ -377,7 +363,7 @@ The available message iterator class methods to implement are:
     successfully
     (it returns
     #BT_MESSAGE_ITERATOR_CLASS_SEEK_BEGINNING_METHOD_STATUS_OK),
-    then your message iterator's next messages (the next time your
+    then the next messages of your message iterator (the next time your
     \link api-msg-iter-cls-meth-next "next" method\endlink
     is called) must be A, B, C, D, and E.
 
@@ -402,8 +388,8 @@ The available message iterator class methods to implement are:
     The optional
     \ref api-msg-iter-cls-meth-can-seek-beg "can seek beginning?"
     method can indicate whether or not your message iterator can
-    currently seek its beginning. If you implement it, the library
-    guarantees that it is called and returns #BT_TRUE before this "seek
+    currently seek its beginning. If you implement it, then the library
+    guarantees that it's called and returns #BT_TRUE before this "seek
     beginning" is called, without any other message iterator methods
     being called in between.
 
@@ -417,14 +403,14 @@ The available message iterator class methods to implement are:
   </dt>
   <dd>
     Called within bt_message_iterator_seek_ns_from_origin() to make
-    your message iterator seek a message occuring at or after a specific
+    your message iterator seek a message occurring at or after a specific
     time given in nanoseconds from its
     \ref api-tir-clock-cls-origin "clock class origin".
 
     Within this method, your receive the specific time to seek as the
     \bt_p{ns_from_origin} parameter. You don't receive any
     \bt_clock_cls: the method operates at the nanosecond from some
-    origin level and it is left to the implementation to seek a message
+    origin level and it's left to the implementation to seek a message
     having at least this time while still honouring the
     \ref api-msg-seq "message sequence rules" the next time your
     \link api-msg-iter-cls-meth-next "next" method\endlink is called.
@@ -434,21 +420,21 @@ The available message iterator class methods to implement are:
     this method, then the next time your
     \link api-msg-iter-cls-meth-next "next" method\endlink is called:
 
-    - For each "active" \bt_stream at the seeked time point, you must
+    - For each "active" \bt_stream at the sought time point, you must
       emit a \bt_sb_msg for this stream before you emit any other
       message for this stream.
 
       The stream beginning message must have a
       \ref api-msg-sb-prop-cs "default clock snapshot" which corresponds
-      to the seeked time point.
+      to the sought time point.
 
-    - For each "active" \bt_pkt at the seeked time point, you must
+    - For each "active" \bt_pkt at the sought time point, you must
       emit a \bt_pb_msg for this packet before you emit any other
       message for this packet.
 
       The packet beginning message must have a
       \ref api-msg-pb-prop-cs "default clock snapshot" which corresponds
-      to the seeked time point.
+      to the sought time point.
 
     The \bt_name project recommends that this method executes fast
     enough so as not to block an interactive application running on the
@@ -465,16 +451,16 @@ The available message iterator class methods to implement are:
     later.
 
     If you need to block the thread to make your message iterator seek a
-    message occuring at or after a given time, you can instead report to
+    message occurring at or after a given time, you can instead report to
     try again later to the caller by returning
     #BT_MESSAGE_ITERATOR_CLASS_SEEK_NS_FROM_ORIGIN_METHOD_STATUS_AGAIN.
 
     The optional
     \ref api-msg-iter-cls-meth-can-seek-ns "can seek ns from origin?"
     method can indicate whether or not your message iterator can
-    currently seek a specific time. If you implement it, the library
-    guarantees that it is called and returns #BT_TRUE before this "seek
-    ns from origin" is called, without any other message iterator
+    currently seek a specific time. If you implement it, then the
+    library guarantees that it's called and returns #BT_TRUE before this
+    "seek ns from origin" is called, without any other message iterator
     methods being called in between.
 
     Set this optional method with the \bt_p{seek_method} parameter
@@ -482,8 +468,9 @@ The available message iterator class methods to implement are:
   </dd>
 </dl>
 
-Within any method, you can access the \bt_msg_iter's \bt_comp's
-configured \ref #bt_logging_level "logging level" by first upcasting the
+Within any method, you can access the
+configured \ref #bt_logging_level "logging level" of the \bt_comp of the
+\bt_msg_iter by first upcasting the
 \bt_self_comp to the #bt_component type with
 bt_self_component_as_component(), and then with
 bt_component_get_logging_level().
@@ -620,7 +607,7 @@ method.
 @param[out] can_seek_ns_from_origin
     <strong>On success</strong>, set \bt_p{*can_seek_ns_from_origin} to
     #BT_TRUE if \bt_p{self_message_iterator} can currently seek a
-    message occuring at or after \bt_p{ns_from_origin} nanoseconds from
+    message occurring at or after \bt_p{ns_from_origin} nanoseconds from
     its \ref api-tir-clock-cls-origin "clock class origin".
 
 @retval #BT_MESSAGE_ITERATOR_CLASS_CAN_SEEK_NS_FROM_ORIGIN_METHOD_STATUS_OK
@@ -700,7 +687,7 @@ See the \ref api-msg-iter-cls-meth-init "initialize" method.
 @param[in] self_message_iterator
     Message iterator instance.
 @param[in] configuration
-    Message iterator's configuration.
+    Configuration of the message iterator.
 @param[in] port
     \bt_c_oport for which \bt_p{self_message_iterator} was created.
 
@@ -992,7 +979,8 @@ typedef bt_message_iterator_class_seek_ns_from_origin_method_status
 */
 extern bt_message_iterator_class *
 bt_message_iterator_class_create(
-		bt_message_iterator_class_next_method next_method);
+		bt_message_iterator_class_next_method next_method)
+		__BT_NOEXCEPT;
 
 /*! @} */
 
@@ -1037,7 +1025,7 @@ See the \ref api-msg-iter-cls-meth-fini "finalize" method.
 extern bt_message_iterator_class_set_method_status
 bt_message_iterator_class_set_finalize_method(
 		bt_message_iterator_class *message_iterator_class,
-		bt_message_iterator_class_finalize_method method);
+		bt_message_iterator_class_finalize_method method) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1062,7 +1050,8 @@ See the \ref api-msg-iter-cls-meth-init "initialize" method.
 extern bt_message_iterator_class_set_method_status
 bt_message_iterator_class_set_initialize_method(
 		bt_message_iterator_class *message_iterator_class,
-		bt_message_iterator_class_initialize_method method);
+		bt_message_iterator_class_initialize_method method)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1084,7 +1073,7 @@ methods.
     @parblock
     New "can seek beginning?" method of \bt_p{message_iterator_class}.
 
-    Can be \c NULL, in which case it is equivalent to setting a method
+    Can be \c NULL, in which case it's equivalent to setting a method
     which always returns #BT_TRUE.
     @endparblock
 
@@ -1099,7 +1088,8 @@ extern bt_message_iterator_class_set_method_status
 bt_message_iterator_class_set_seek_beginning_methods(
 		bt_message_iterator_class *message_iterator_class,
 		bt_message_iterator_class_seek_beginning_method seek_method,
-		bt_message_iterator_class_can_seek_beginning_method can_seek_method);
+		bt_message_iterator_class_can_seek_beginning_method can_seek_method)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1123,7 +1113,7 @@ methods.
     New "can seek ns from origin?" method of
     \bt_p{message_iterator_class}.
 
-    Can be \c NULL, in which case it is equivalent to setting a method
+    Can be \c NULL, in which case it's equivalent to setting a method
     which always returns #BT_TRUE.
     @endparblock
 
@@ -1138,7 +1128,8 @@ extern bt_message_iterator_class_set_method_status
 bt_message_iterator_class_set_seek_ns_from_origin_methods(
 		bt_message_iterator_class *message_iterator_class,
 		bt_message_iterator_class_seek_ns_from_origin_method seek_method,
-		bt_message_iterator_class_can_seek_ns_from_origin_method can_seek_method);
+		bt_message_iterator_class_can_seek_ns_from_origin_method can_seek_method)
+		__BT_NOEXCEPT;
 
 /*! @} */
 
@@ -1163,7 +1154,8 @@ bt_message_iterator_class_set_seek_ns_from_origin_methods(
     Decrements the reference count of a message iterator class.
 */
 extern void bt_message_iterator_class_get_ref(
-		const bt_message_iterator_class *message_iterator_class);
+		const bt_message_iterator_class *message_iterator_class)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1181,7 +1173,8 @@ extern void bt_message_iterator_class_get_ref(
     Increments the reference count of a message iterator class.
 */
 extern void bt_message_iterator_class_put_ref(
-		const bt_message_iterator_class *message_iterator_class);
+		const bt_message_iterator_class *message_iterator_class)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
