@@ -1,27 +1,13 @@
+/*
+ * SPDX-License-Identifier: MIT
+ *
+ * Copyright (C) 2010-2019 EfficiOS Inc. and Linux Foundation
+ */
+
 #ifndef BABELTRACE2_GRAPH_MESSAGE_ITERATOR_H
 #define BABELTRACE2_GRAPH_MESSAGE_ITERATOR_H
 
-/*
- * Copyright (c) 2010-2019 EfficiOS Inc. and Linux Foundation
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
+/* IWYU pragma: private, include <babeltrace2/babeltrace.h> */
 
 #ifndef __BT_IN_BABELTRACE_H
 # error "Please include <babeltrace2/babeltrace.h> instead."
@@ -49,7 +35,7 @@ trace data (\bt_p_ev, for example).
 A message iterator is a \bt_msg_iter_cls instance. Because a message
 iterator class is part of a \bt_src_comp_cls or \bt_flt_comp_cls, a
 message iterator is part of a \bt_src_comp or \bt_flt_comp. Borrow
-a message iterator's component with
+the component of a message iterator with
 bt_message_iterator_borrow_component().
 
 A message iterator is a \ref api-fund-shared-object "shared object": get
@@ -63,7 +49,7 @@ There are two contexts from which you can create a message iterator:
 <dl>
   <dt>From another message iterator</dt>
   <dd>
-    This is the case for a \bt_flt_comp's message iterator.
+    This is the case for the message iterator of a \bt_flt_comp.
 
     Use bt_message_iterator_create_from_message_iterator().
 
@@ -101,12 +87,12 @@ other \bt_p_comp. Then:
   on any of its connected input ports.
 
 - Any message iterator is free to create one or more message iterators
-  on any of its component's connected input ports.
+  on any of the connected input ports of its component.
 
 The following illustration shows a very simple use case where the
 \ref api-comp-cls-dev-meth-consume "consuming method" of a sink
-component uses a single \bt_flt_comp's message iterator which itself
-uses a single \bt_src_comp's message iterator:
+component uses a single \bt_flt_comp message iterator which itself
+uses a single \bt_src_comp message iterator:
 
 @image html msg-iter.png
 
@@ -122,11 +108,11 @@ operations:
 <dl>
   <dt>
     \anchor api-msg-iter-op-next
-    Get the message iterator's next messages
+    Get the next messages of the message iterator.
   </dt>
   <dd>
-    This operation returns a batch of the message iterator's next
-    \bt_p_msg considering its current state.
+    This operation returns a batch of the next
+    \bt_p_msg of the message iterator considering its current state.
 
     This operation returns a batch of messages instead of a single
     message for performance reasons.
@@ -142,15 +128,15 @@ operations:
     Make the message iterator seek its beginning
   </dt>
   <dd>
-    This operation resets the message iterator's position to the
+    This operation resets the position of the message iterator to the
     beginning of its \ref api-msg-seq "message sequence".
 
     If the operation is successful, then the next call to
     bt_message_iterator_next() returns the first \bt_p_msg of the
-    message iterator's sequence.
+    sequence of the message iterator.
 
     If bt_message_iterator_seek_ns_from_origin() returns something
-    else than #BT_MESSAGE_ITERATOR_SEEK_BEGINNING_STATUS_OK, you
+    else than #BT_MESSAGE_ITERATOR_SEEK_BEGINNING_STATUS_OK, then you
     \em cannot call bt_message_iterator_next() afterwards. In that case,
     you can only call bt_message_iterator_seek_beginning() again or
     bt_message_iterator_seek_ns_from_origin().
@@ -176,19 +162,19 @@ operations:
     the operation, your pass the specific time to seek as the
     \bt_p{ns_from_origin} parameter. You don't pass any
     \bt_clock_cls: the function operates at the nanosecond from some
-    origin level and it is left to the message iterator's implementation
-    to seek a message having at least this time.
+    origin level and it's left to the implementation of the message
+    iterator to seek a message having at least this time.
 
-    If the requested time point is \em after the message iterator's
-    sequence's last message, then the next call to
+    If the requested time point is \em after the last message of the
+    sequence of the message iterator, then the next call to
     bt_message_iterator_next() returns
     #BT_MESSAGE_ITERATOR_NEXT_STATUS_END.
 
     If bt_message_iterator_seek_ns_from_origin() returns something
-    else than #BT_MESSAGE_ITERATOR_SEEK_NS_FROM_ORIGIN_STATUS_OK, you
-    \em cannot call bt_message_iterator_next() afterwards. In that case,
-    you can only call bt_message_iterator_seek_ns_from_origin() again
-    or bt_message_iterator_seek_beginning().
+    else than #BT_MESSAGE_ITERATOR_SEEK_NS_FROM_ORIGIN_STATUS_OK, then
+    you \em cannot call bt_message_iterator_next() afterwards. In that
+    case, you can only call bt_message_iterator_seek_ns_from_origin()
+    again or bt_message_iterator_seek_beginning().
 
     Before you call bt_message_iterator_seek_ns_from_origin() to make
     the message iterator seek a specific point in time, check if it can
@@ -246,8 +232,8 @@ typedef enum bt_message_iterator_create_from_message_iterator_status {
     another message iterator \bt_p{self_message_iterator}, and sets
     \bt_p{*message_iterator} to the resulting message iterator.
 
-On success, the message iterator's position is at the beginning
-of its \ref api-msg-seq "message sequence".
+On success, the position of \bt_p{*message_iterator} is at the
+beginning of its \ref api-msg-seq "message sequence".
 
 @param[in] self_message_iterator
     Other message iterator from which to create the message iterator.
@@ -262,8 +248,9 @@ of its \ref api-msg-seq "message sequence".
 @retval #BT_MESSAGE_ITERATOR_CREATE_FROM_MESSAGE_ITERATOR_STATUS_MEMORY_ERROR
     Out of memory.
 @retval #BT_MESSAGE_ITERATOR_CREATE_FROM_MESSAGE_ITERATOR_STATUS_ERROR
-    Other error, for example, the created message iterator's
-    \ref api-msg-iter-cls-meth-init "initialization method" failed.
+    Other error, for example, the
+    \ref api-msg-iter-cls-meth-init "initialization method" of the
+    created message iterator failed.
 
 @bt_pre_not_null{self_message_iterator}
 @bt_pre_not_null{port}
@@ -278,7 +265,7 @@ extern bt_message_iterator_create_from_message_iterator_status
 bt_message_iterator_create_from_message_iterator(
 		bt_self_message_iterator *self_message_iterator,
 		bt_self_component_port_input *port,
-		bt_message_iterator **message_iterator);
+		bt_message_iterator **message_iterator) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -310,7 +297,7 @@ typedef enum bt_message_iterator_create_from_sink_component_status {
     \bt_sink_comp \bt_p{self_component_sink}, and sets
     \bt_p{*message_iterator} to the resulting message iterator.
 
-On success, the message iterator's position is at the beginning
+On success, the position of \bt_p{*message_iterator} is at the beginning
 of its \ref api-msg-seq "message sequence".
 
 @param[in] self_component_sink
@@ -326,8 +313,9 @@ of its \ref api-msg-seq "message sequence".
 @retval #BT_MESSAGE_ITERATOR_CREATE_FROM_MESSAGE_ITERATOR_STATUS_MEMORY_ERROR
     Out of memory.
 @retval #BT_MESSAGE_ITERATOR_CREATE_FROM_MESSAGE_ITERATOR_STATUS_ERROR
-    Other error, for example, the created message iterator's
-    \ref api-msg-iter-cls-meth-init "initialization method" failed.
+    Other error, for example, the
+    \ref api-msg-iter-cls-meth-init "initialization method" of the
+    created message iterator failed.
 
 @bt_pre_not_null{self_component_sink}
 @bt_pre_not_null{port}
@@ -342,7 +330,7 @@ extern bt_message_iterator_create_from_sink_component_status
 bt_message_iterator_create_from_sink_component(
 		bt_self_component_sink *self_component_sink,
 		bt_self_component_port_input *port,
-		bt_message_iterator **message_iterator);
+		bt_message_iterator **message_iterator) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -367,7 +355,7 @@ bt_message_iterator_create_from_sink_component(
 */
 extern bt_component *
 bt_message_iterator_borrow_component(
-		bt_message_iterator *message_iterator);
+		bt_message_iterator *message_iterator) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -418,10 +406,10 @@ typedef enum bt_message_iterator_next_status {
     \bt_p{message_iterator} into the \bt_p{*messages} array of size
     \bt_p{*count}, effectively advancing \bt_p{message_iterator}.
 
-See \ref api-msg-iter-op-next "this operation's documentation".
+See \ref api-msg-iter-op-next "the documentation of this operation".
 
-On success, the message iterator's position is advanced by \bt_p{*count}
-messages.
+On success, the position of \bt_p{message_iterator} is advanced by
+\bt_p{*count} messages.
 
 @param[in] message_iterator
     Message iterator from which to get the next messages.
@@ -434,7 +422,7 @@ messages.
 
     The library allocates and manages this array, but until you
     perform another \ref api-msg-iter-ops "operation" on
-    \bt_p{message_iterator}, you are free to modify it. For example,
+    \bt_p{message_iterator}, you're free to modify it. For example,
     you can set its elements to \c NULL if your use case needs it.
 
     You own the references of the messages this array contains. In
@@ -468,7 +456,8 @@ messages.
 */
 extern bt_message_iterator_next_status
 bt_message_iterator_next(bt_message_iterator *message_iterator,
-		bt_message_array_const *messages, uint64_t *count);
+		bt_message_array_const *messages, uint64_t *count)
+		__BT_NOEXCEPT;
 
 /*! @} */
 
@@ -544,7 +533,7 @@ call bt_message_iterator_seek_beginning().
 extern bt_message_iterator_can_seek_beginning_status
 bt_message_iterator_can_seek_beginning(
 		bt_message_iterator *message_iterator,
-		bt_bool *can_seek_beginning);
+		bt_bool *can_seek_beginning) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -581,7 +570,7 @@ typedef enum bt_message_iterator_seek_beginning_status {
     Makes the message iterator \bt_p{message_iterator} seek its
     beginning (first \bt_msg).
 
-See \ref api-msg-iter-op-seek-beg "this operation's documentation".
+See \ref api-msg-iter-op-seek-beg "the documentation of this operation".
 
 Make sure to call bt_message_iterator_can_seek_beginning(),
 without performing any other \ref api-msg-iter-ops "operation" on
@@ -610,7 +599,7 @@ without performing any other \ref api-msg-iter-ops "operation" on
 */
 extern bt_message_iterator_seek_beginning_status
 bt_message_iterator_seek_beginning(
-		bt_message_iterator *message_iterator);
+		bt_message_iterator *message_iterator) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -687,7 +676,8 @@ call bt_message_iterator_seek_ns_from_origin().
 extern bt_message_iterator_can_seek_ns_from_origin_status
 bt_message_iterator_can_seek_ns_from_origin(
 		bt_message_iterator *message_iterator,
-		int64_t ns_from_origin, bt_bool *can_seek_ns_from_origin);
+		int64_t ns_from_origin, bt_bool *can_seek_ns_from_origin)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -725,7 +715,7 @@ typedef enum bt_message_iterator_seek_ns_from_origin_status {
     occurring at or after \bt_p{ns_from_origin} nanoseconds from its
     \ref api-tir-clock-cls-origin "clock class origin".
 
-See \ref api-msg-iter-op-seek-ns "this operation's documentation".
+See \ref api-msg-iter-op-seek-ns "the documentation of this operation".
 
 Make sure to call bt_message_iterator_can_seek_ns_from_origin(),
 without performing any other \ref api-msg-iter-ops "operation" on
@@ -759,7 +749,7 @@ without performing any other \ref api-msg-iter-ops "operation" on
 extern bt_message_iterator_seek_ns_from_origin_status
 bt_message_iterator_seek_ns_from_origin(
 		bt_message_iterator *message_iterator,
-		int64_t ns_from_origin);
+		int64_t ns_from_origin) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -787,7 +777,7 @@ message sequence have some \bt_cs.
 */
 extern bt_bool
 bt_message_iterator_can_seek_forward(
-		bt_message_iterator *message_iterator);
+		bt_message_iterator *message_iterator) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -812,7 +802,7 @@ bt_message_iterator_can_seek_forward(
     Decrements the reference count of a message iterator.
 */
 extern void bt_message_iterator_get_ref(
-		const bt_message_iterator *message_iterator);
+		const bt_message_iterator *message_iterator) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -830,7 +820,7 @@ extern void bt_message_iterator_get_ref(
     Increments the reference count of a message iterator.
 */
 extern void bt_message_iterator_put_ref(
-		const bt_message_iterator *message_iterator);
+		const bt_message_iterator *message_iterator) __BT_NOEXCEPT;
 
 /*!
 @brief
