@@ -1,27 +1,13 @@
+/*
+ * SPDX-License-Identifier: MIT
+ *
+ * Copyright (C) 2010-2019 EfficiOS Inc. and Linux Foundation
+ */
+
 #ifndef BABELTRACE2_GRAPH_SELF_COMPONENT_H
 #define BABELTRACE2_GRAPH_SELF_COMPONENT_H
 
-/*
- * Copyright (c) 2010-2019 EfficiOS Inc. and Linux Foundation
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
+/* IWYU pragma: private, include <babeltrace2/babeltrace.h> */
 
 #ifndef __BT_IN_BABELTRACE_H
 # error "Please include <babeltrace2/babeltrace.h> instead."
@@ -70,8 +56,8 @@ bt_self_component_sink_borrow_input_port_by_name().
 Set and get user data attached to a component with
 bt_self_component_set_data() and bt_self_component_get_data().
 
-Get a component's owning trace processing \bt_graph's effective
-\bt_mip version with bt_self_component_get_graph_mip_version().
+Get the effective \bt_mip version of the owning trace processing
+\bt_graph of a component with bt_self_component_get_graph_mip_version().
 
 Check whether or not a \bt_sink_comp is interrupted with
 bt_self_component_sink_is_interrupted().
@@ -165,7 +151,7 @@ typedef enum bt_self_component_add_port_status {
     and sets \bt_p{*self_component_port} to the resulting port.
 
 @attention
-    You can only call this function from within the
+    You may only call this function from within the
     \ref api-comp-cls-dev-meth-init "initialization",
     \link api-comp-cls-dev-meth-iport-connected "input port connected"\endlink,
     and
@@ -200,7 +186,8 @@ extern bt_self_component_add_port_status
 bt_self_component_source_add_output_port(
 		bt_self_component_source *self_component,
 		const char *name, void *user_data,
-		bt_self_component_port_output **self_component_port);
+		bt_self_component_port_output **self_component_port)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -209,7 +196,7 @@ bt_self_component_source_add_output_port(
     and sets \bt_p{*self_component_port} to the resulting port.
 
 @attention
-    You can only call this function from within the
+    You may only call this function from within the
     \ref api-comp-cls-dev-meth-init "initialization",
     \link api-comp-cls-dev-meth-iport-connected "input port connected"\endlink,
     and
@@ -244,7 +231,8 @@ extern bt_self_component_add_port_status
 bt_self_component_filter_add_input_port(
 		bt_self_component_filter *self_component,
 		const char *name, void *user_data,
-		bt_self_component_port_input **self_component_port);
+		bt_self_component_port_input **self_component_port)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -253,7 +241,7 @@ bt_self_component_filter_add_input_port(
     and sets \bt_p{*self_component_port} to the resulting port.
 
 @attention
-    You can only call this function from within the
+    You may only call this function from within the
     \ref api-comp-cls-dev-meth-init "initialization",
     \link api-comp-cls-dev-meth-iport-connected "input port connected"\endlink,
     and
@@ -288,7 +276,8 @@ extern bt_self_component_add_port_status
 bt_self_component_filter_add_output_port(
 		bt_self_component_filter *self_component,
 		const char *name, void *user_data,
-		bt_self_component_port_output **self_component_port);
+		bt_self_component_port_output **self_component_port)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -297,7 +286,7 @@ bt_self_component_filter_add_output_port(
     and sets \bt_p{*self_component_port} to the resulting port.
 
 @attention
-    You can only call this function from within the
+    You may only call this function from within the
     \ref api-comp-cls-dev-meth-init "initialization",
     \link api-comp-cls-dev-meth-iport-connected "input port connected"\endlink,
     and
@@ -333,7 +322,8 @@ extern bt_self_component_add_port_status
 bt_self_component_sink_add_input_port(
 		bt_self_component_sink *self_component,
 		const char *name, void *user_data,
-		bt_self_component_port_input **self_component_port);
+		bt_self_component_port_input **self_component_port)
+		__BT_NOEXCEPT;
 
 /*! @} */
 
@@ -373,7 +363,7 @@ bt_self_component_sink_add_input_port(
 extern bt_self_component_port_output *
 bt_self_component_source_borrow_output_port_by_index(
 		bt_self_component_source *self_component,
-		uint64_t index);
+		uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -406,7 +396,7 @@ bt_self_component_source_borrow_output_port_by_index(
 extern bt_self_component_port_input *
 bt_self_component_filter_borrow_input_port_by_index(
 		bt_self_component_filter *self_component,
-		uint64_t index);
+		uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -439,7 +429,7 @@ bt_self_component_filter_borrow_input_port_by_index(
 extern bt_self_component_port_output *
 bt_self_component_filter_borrow_output_port_by_index(
 		bt_self_component_filter *self_component,
-		uint64_t index);
+		uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -471,14 +461,15 @@ bt_self_component_filter_borrow_output_port_by_index(
 */
 extern bt_self_component_port_input *
 bt_self_component_sink_borrow_input_port_by_index(
-		bt_self_component_sink *self_component, uint64_t index);
+		bt_self_component_sink *self_component, uint64_t index)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
     Borrows the \bt_self_comp_oport named \bt_p{name} from the
     \bt_src_comp \bt_p{self_component}.
 
-If \bt_p{self_component} has no output port named \bt_p{name}, this
+If \bt_p{self_component} has no output port named \bt_p{name}, then this
 function returns \c NULL.
 
 @param[in] self_component
@@ -501,14 +492,14 @@ function returns \c NULL.
 extern bt_self_component_port_output *
 bt_self_component_source_borrow_output_port_by_name(
 		bt_self_component_source *self_component,
-		const char *name);
+		const char *name) __BT_NOEXCEPT;
 
 /*!
 @brief
     Borrows the \bt_self_comp_iport named \bt_p{name} from the
     \bt_flt_comp \bt_p{self_component}.
 
-If \bt_p{self_component} has no input port named \bt_p{name}, this
+If \bt_p{self_component} has no input port named \bt_p{name}, then this
 function returns \c NULL.
 
 @param[in] self_component
@@ -531,14 +522,14 @@ function returns \c NULL.
 extern bt_self_component_port_input *
 bt_self_component_filter_borrow_input_port_by_name(
 		bt_self_component_filter *self_component,
-		const char *name);
+		const char *name) __BT_NOEXCEPT;
 
 /*!
 @brief
     Borrows the \bt_self_comp_oport named \bt_p{name} from the
     \bt_flt_comp \bt_p{self_component}.
 
-If \bt_p{self_component} has no output port named \bt_p{name}, this
+If \bt_p{self_component} has no output port named \bt_p{name}, then this
 function returns \c NULL.
 
 @param[in] self_component
@@ -561,14 +552,14 @@ function returns \c NULL.
 extern bt_self_component_port_output *
 bt_self_component_filter_borrow_output_port_by_name(
 		bt_self_component_filter *self_component,
-		const char *name);
+		const char *name) __BT_NOEXCEPT;
 
 /*!
 @brief
     Borrows the \bt_self_comp_iport named \bt_p{name} from the
     \bt_sink_comp \bt_p{self_component}.
 
-If \bt_p{self_component} has no input port named \bt_p{name}, this
+If \bt_p{self_component} has no input port named \bt_p{name}, then this
 function returns \c NULL.
 
 @param[in] self_component
@@ -591,7 +582,7 @@ function returns \c NULL.
 extern bt_self_component_port_input *
 bt_self_component_sink_borrow_input_port_by_name(
 		bt_self_component_sink *self_component,
-		const char *name);
+		const char *name) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -616,7 +607,8 @@ bt_self_component_sink_borrow_input_port_by_name(
     Returns the user data of a component.
 */
 extern void bt_self_component_set_data(
-		bt_self_component *self_component, void *user_data);
+		bt_self_component *self_component, void *user_data)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -634,12 +626,12 @@ extern void bt_self_component_set_data(
     Sets the user data of a component.
 */
 extern void *bt_self_component_get_data(
-		const bt_self_component *self_component);
+		const bt_self_component *self_component) __BT_NOEXCEPT;
 
 /*! @} */
 
 /*!
-@name Trace processing graph's effective MIP version access
+@name Effective Message Interchange Protocol (MIP) version access
 @{
 */
 
@@ -648,10 +640,6 @@ extern void *bt_self_component_get_data(
     Returns the effective \bt_mip (MIP) version of the trace processing
     \bt_graph which contains the \bt_comp \bt_p{self_component}.
 
-@note
-    As of \bt_name_version_min_maj, because bt_get_maximal_mip_version()
-    returns 0, this function always returns 0.
-
 @param[in] self_component
     Component instance.
 
@@ -663,12 +651,12 @@ extern void *bt_self_component_get_data(
 */
 extern
 uint64_t bt_self_component_get_graph_mip_version(
-		bt_self_component *self_component);
+		bt_self_component *self_component) __BT_NOEXCEPT;
 
 /*! @} */
 
 /*!
-@name Sink component's interruption query
+@name Interruption query of a sink component
 @{
 */
 
@@ -688,12 +676,12 @@ uint64_t bt_self_component_get_graph_mip_version(
 @bt_pre_not_null{self_component}
 
 @sa bt_graph_borrow_default_interrupter() &mdash;
-    Borrows a trace processing graph's default interrupter.
+    Borrows the default interrupter of a trace processing graph.
 @sa bt_graph_add_interrupter() &mdash;
     Adds an interrupter to a graph.
 */
 extern bt_bool bt_self_component_sink_is_interrupted(
-		const bt_self_component_sink *self_component);
+		const bt_self_component_sink *self_component) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -719,7 +707,7 @@ extern bt_bool bt_self_component_sink_is_interrupted(
 */
 static inline
 const bt_component *bt_self_component_as_component(
-		bt_self_component *self_component)
+		bt_self_component *self_component) __BT_NOEXCEPT
 {
 	return __BT_UPCAST(bt_component, self_component);
 }
@@ -743,7 +731,7 @@ const bt_component *bt_self_component_as_component(
 static inline
 const bt_component_source *
 bt_self_component_source_as_component_source(
-		bt_self_component_source *self_component)
+		bt_self_component_source *self_component) __BT_NOEXCEPT
 {
 	return __BT_UPCAST_CONST(bt_component_source, self_component);
 }
@@ -767,7 +755,7 @@ bt_self_component_source_as_component_source(
 static inline
 const bt_component_filter *
 bt_self_component_filter_as_component_filter(
-		bt_self_component_filter *self_component)
+		bt_self_component_filter *self_component) __BT_NOEXCEPT
 {
 	return __BT_UPCAST_CONST(bt_component_filter, self_component);
 }
@@ -791,7 +779,7 @@ bt_self_component_filter_as_component_filter(
 static inline
 const bt_component_sink *
 bt_self_component_sink_as_component_sink(
-		bt_self_component_sink *self_component)
+		bt_self_component_sink *self_component) __BT_NOEXCEPT
 {
 	return __BT_UPCAST_CONST(bt_component_sink, self_component);
 }
@@ -821,7 +809,7 @@ bt_self_component_sink_as_component_sink(
 */
 static inline
 bt_self_component *bt_self_component_source_as_self_component(
-		bt_self_component_source *self_component)
+		bt_self_component_source *self_component) __BT_NOEXCEPT
 {
 	return __BT_UPCAST(bt_self_component, self_component);
 }
@@ -844,7 +832,7 @@ bt_self_component *bt_self_component_source_as_self_component(
 */
 static inline
 bt_self_component *bt_self_component_filter_as_self_component(
-		bt_self_component_filter *self_component)
+		bt_self_component_filter *self_component) __BT_NOEXCEPT
 {
 	return __BT_UPCAST(bt_self_component, self_component);
 }
@@ -867,7 +855,7 @@ bt_self_component *bt_self_component_filter_as_self_component(
 */
 static inline
 bt_self_component *bt_self_component_sink_as_self_component(
-		bt_self_component_sink *self_component)
+		bt_self_component_sink *self_component) __BT_NOEXCEPT
 {
 	return __BT_UPCAST(bt_self_component, self_component);
 }
