@@ -1,25 +1,7 @@
 /*
+ * SPDX-License-Identifier: MIT
+ *
  * Copyright 2010-2011 EfficiOS Inc. and Linux Foundation
- *
- * Author: Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
  */
 
 #define BT_LOG_TAG "CLI"
@@ -46,6 +28,7 @@
 
 #define ENV_BABELTRACE_WARN_COMMAND_NAME_DIRECTORY_CLASH "BABELTRACE_CLI_WARN_COMMAND_NAME_DIRECTORY_CLASH"
 #define NSEC_PER_SEC	1000000000LL
+#define EXIT_INTERRUPTED 2
 
 enum bt_cmd_status {
 	BT_CMD_STATUS_OK	    = 0,
@@ -76,7 +59,7 @@ static bt_interrupter *the_interrupter;
 #include <windows.h>
 
 static
-BOOL WINAPI signal_handler(DWORD signal) {
+BOOL WINAPI signal_handler(DWORD signal __attribute__((unused))) {
 	if (the_interrupter) {
 		bt_interrupter_set(the_interrupter);
 	}
@@ -270,7 +253,9 @@ end:
 
 static
 bt_value_map_foreach_entry_const_func_status collect_map_keys(
-		const char *key, const bt_value *object, void *data)
+		const char *key,
+		const bt_value *object __attribute__((unused)),
+		void *data)
 {
 	GPtrArray *map_keys = data;
 
@@ -653,10 +638,11 @@ enum bt_cmd_status cmd_query(struct bt_config *cfg)
 	if (!comp_cls) {
 		BT_CLI_LOGE_APPEND_CAUSE(
 			"Cannot find component class: plugin-name=\"%s\", "
-			"comp-cls-name=\"%s\", comp-cls-type=%d",
+			"comp-cls-name=\"%s\", comp-cls-type=%s",
 			cfg->cmd_data.query.cfg_component->plugin_name->str,
 			cfg->cmd_data.query.cfg_component->comp_cls_name->str,
-			cfg->cmd_data.query.cfg_component->type);
+			bt_common_component_class_type_string(
+				cfg->cmd_data.query.cfg_component->type));
 		goto error;
 	}
 
@@ -666,11 +652,12 @@ enum bt_cmd_status cmd_query(struct bt_config *cfg)
 	if (ret) {
 		BT_CLI_LOGE_APPEND_CAUSE(
 			"Failed to query component class: %s: plugin-name=\"%s\", "
-			"comp-cls-name=\"%s\", comp-cls-type=%d "
+			"comp-cls-name=\"%s\", comp-cls-type=%s "
 			"object=\"%s\"", fail_reason,
 			cfg->cmd_data.query.cfg_component->plugin_name->str,
 			cfg->cmd_data.query.cfg_component->comp_cls_name->str,
-			cfg->cmd_data.query.cfg_component->type,
+			bt_common_component_class_type_string(
+				cfg->cmd_data.query.cfg_component->type),
 			cfg->cmd_data.query.object->str);
 		goto error;
 	}
@@ -760,10 +747,11 @@ enum bt_cmd_status cmd_help(struct bt_config *cfg)
 	if (!needed_comp_cls) {
 		BT_CLI_LOGE_APPEND_CAUSE(
 			"Cannot find component class: plugin-name=\"%s\", "
-			"comp-cls-name=\"%s\", comp-cls-type=%d",
+			"comp-cls-name=\"%s\", comp-cls-type=%s",
 			cfg->cmd_data.help.cfg_component->plugin_name->str,
 			cfg->cmd_data.help.cfg_component->comp_cls_name->str,
-			cfg->cmd_data.help.cfg_component->type);
+			bt_common_component_class_type_string(
+				cfg->cmd_data.help.cfg_component->type));
 		goto error;
 	}
 
@@ -921,9 +909,10 @@ enum bt_cmd_status cmd_print_lttng_live_sessions(struct bt_config *cfg)
 	if (!comp_cls) {
 		BT_CLI_LOGE_APPEND_CAUSE(
 			"Cannot find component class: plugin-name=\"%s\", "
-			"comp-cls-name=\"%s\", comp-cls-type=%d",
+			"comp-cls-name=\"%s\", comp-cls-type=%s",
 			plugin_name, comp_cls_name,
-			BT_COMPONENT_CLASS_TYPE_SOURCE);
+			bt_common_component_class_type_string(
+				BT_COMPONENT_CLASS_TYPE_SOURCE));
 		goto error;
 	}
 
@@ -972,7 +961,7 @@ enum bt_cmd_status cmd_print_lttng_live_sessions(struct bt_config *cfg)
 
 	array_size = bt_value_array_get_length(results);
 	for (i = 0; i < array_size; i++) {
-		const char *url_text;
+		const char *text;
 		int64_t timer_us, streams, clients;
 
 		map = bt_value_array_borrow_element_by_index_const(results, i);
@@ -986,8 +975,8 @@ enum bt_cmd_status cmd_print_lttng_live_sessions(struct bt_config *cfg)
 			BT_CLI_LOGE_APPEND_CAUSE("Missing `url` entry.");
 			goto error;
 		}
-		url_text = bt_value_string_get(v);
-		fprintf(out_stream, "%s", url_text);
+		text = bt_value_string_get(v);
+		fprintf(out_stream, "%s", text);
 		v = bt_value_map_borrow_entry_value_const(map, "timer-us");
 		if (!v) {
 			BT_CLI_LOGE_APPEND_CAUSE("Missing `timer-us` entry.");
@@ -1010,7 +999,25 @@ enum bt_cmd_status cmd_print_lttng_live_sessions(struct bt_config *cfg)
 			goto error;
 		}
 		clients = bt_value_integer_unsigned_get(v);
-		fprintf(out_stream, "%" PRIu64 " client(s) connected)\n", clients);
+		fprintf(out_stream, "%" PRIu64 " client(s) connected, ", clients);
+		v = bt_value_map_borrow_entry_value_const(map, "trace-format");
+		if (!v) {
+			BT_CLI_LOGE_APPEND_CAUSE("Missing `trace-format` entry.");
+			goto error;
+		}
+		text = bt_value_string_get(v);
+
+		const char *trace_fmt;
+
+		if (strcmp(text, "ctf-1.8") == 0) {
+			fprintf(out_stream, "CTF 1.8)");
+		} else if (strcmp(text, "ctf-2.0") == 0) {
+			fprintf(out_stream, "CTF 2)");
+		} else {
+			fprintf(out_stream, "unknown trace format [`%s`])", trace_fmt);
+		}
+
+		fprintf(out_stream, "\n");
 	}
 
 	cmd_status = BT_CMD_STATUS_OK;
@@ -1060,9 +1067,10 @@ enum bt_cmd_status cmd_print_ctf_metadata(struct bt_config *cfg)
 	if (!comp_cls) {
 		BT_CLI_LOGE_APPEND_CAUSE(
 			"Cannot find component class: plugin-name=\"%s\", "
-			"comp-cls-name=\"%s\", comp-cls-type=%d",
+			"comp-cls-name=\"%s\", comp-cls-type=%s",
 			plugin_name, comp_cls_name,
-			BT_COMPONENT_CLASS_TYPE_SOURCE);
+			bt_common_component_class_type_string(
+				BT_COMPONENT_CLASS_TYPE_SOURCE));
 		goto error;
 	}
 
@@ -1659,7 +1667,7 @@ end:
 
 static
 bt_graph_listener_func_status graph_source_output_port_added_listener(
-		const bt_component_source *component,
+		const bt_component_source *component __attribute__((unused)),
 		const bt_port_output *port, void *data)
 {
 	return graph_output_port_added_listener(data, port);
@@ -1667,7 +1675,7 @@ bt_graph_listener_func_status graph_source_output_port_added_listener(
 
 static
 bt_graph_listener_func_status graph_filter_output_port_added_listener(
-		const bt_component_filter *component,
+		const bt_component_filter *component __attribute__((unused)),
 		const bt_port_output *port, void *data)
 {
 	return graph_output_port_added_listener(data, port);
@@ -1719,8 +1727,9 @@ int add_descriptor_to_component_descriptor_set(
 	if (!comp_cls) {
 		BT_CLI_LOGE_APPEND_CAUSE(
 			"Cannot find component class: plugin-name=\"%s\", "
-			"comp-cls-name=\"%s\", comp-cls-type=%d",
-			plugin_name, comp_cls_name, comp_cls_type);
+			"comp-cls-name=\"%s\", comp-cls-type=%s",
+			plugin_name, comp_cls_name,
+			bt_common_component_class_type_string(comp_cls_type));
 		status = -1;
 		goto end;
 	}
@@ -1772,6 +1781,7 @@ bt_get_greatest_operative_mip_version_status get_greatest_operative_mip_version(
 	bt_get_greatest_operative_mip_version_status status =
 		BT_GET_GREATEST_OPERATIVE_MIP_VERSION_STATUS_OK;
 	bt_component_descriptor_set *comp_descr_set = NULL;
+	bt_integer_range_set_unsigned *mip_version_restriction = NULL;
 	int ret;
 
 	BT_ASSERT(cfg);
@@ -1821,10 +1831,41 @@ bt_get_greatest_operative_mip_version_status get_greatest_operative_mip_version(
 		}
 	}
 
-	status = bt_get_greatest_operative_mip_version(comp_descr_set,
-		bt_cli_log_level, mip_version);
+	/* Set MIP version restrictions if needed */
+	if (!cfg->cmd_data.run.allow_mip_0 || !cfg->cmd_data.run.allow_mip_1) {
+		mip_version_restriction = bt_integer_range_set_unsigned_create();
+		if (!mip_version_restriction) {
+			status = BT_GET_GREATEST_OPERATIVE_MIP_VERSION_STATUS_MEMORY_ERROR;
+			goto end;
+		}
+
+		if (cfg->cmd_data.run.allow_mip_0) {
+			bt_integer_range_set_add_range_status add_range_status =
+				bt_integer_range_set_unsigned_add_range(
+					mip_version_restriction, 0, 0);
+			if (add_range_status != BT_INTEGER_RANGE_SET_ADD_RANGE_STATUS_OK) {
+				status = (int) add_range_status;
+				goto end;
+			}
+		}
+
+		if (cfg->cmd_data.run.allow_mip_1) {
+			bt_integer_range_set_add_range_status add_range_status =
+				bt_integer_range_set_unsigned_add_range(
+					mip_version_restriction, 1, 1);
+			if (add_range_status != BT_INTEGER_RANGE_SET_ADD_RANGE_STATUS_OK) {
+				status = (int) add_range_status;
+				goto end;
+			}
+		}
+	}
+
+	status = bt_get_greatest_operative_mip_version_with_restriction(
+		comp_descr_set, (bt_logging_level) bt_cli_log_level,
+		mip_version_restriction, mip_version);
 
 end:
+	bt_object_put_ref(mip_version_restriction);
 	bt_component_descriptor_set_put_ref(comp_descr_set);
 	return status;
 }
@@ -2256,10 +2297,10 @@ int cmd_run_ctx_create_components_from_config_components(
 		if (!comp_cls) {
 			BT_CLI_LOGE_APPEND_CAUSE(
 				"Cannot find component class: plugin-name=\"%s\", "
-				"comp-cls-name=\"%s\", comp-cls-type=%d",
+				"comp-cls-name=\"%s\", comp-cls-type=%s",
 				cfg_comp->plugin_name->str,
 				cfg_comp->comp_cls_name->str,
-				cfg_comp->type);
+				bt_common_component_class_type_string(cfg_comp->type));
 			goto error;
 		}
 
@@ -2294,11 +2335,12 @@ int cmd_run_ctx_create_components_from_config_components(
 		if (ret) {
 			BT_CLI_LOGE_APPEND_CAUSE(
 				"Cannot create component: plugin-name=\"%s\", "
-				"comp-cls-name=\"%s\", comp-cls-type=%d, "
+				"comp-cls-name=\"%s\", comp-cls-type=%s, "
 				"comp-name=\"%s\"",
 				cfg_comp->plugin_name->str,
 				cfg_comp->comp_cls_name->str,
-				cfg_comp->type, cfg_comp->instance_name->str);
+				bt_common_component_class_type_string(cfg_comp->type),
+				cfg_comp->instance_name->str);
 			goto error;
 		}
 
@@ -2545,7 +2587,7 @@ enum bt_cmd_status cmd_run(struct bt_config *cfg)
 			}
 
 			BT_CLI_LOGE_APPEND_CAUSE(
-				"Graph failed to complete successfully");
+				"Graph failed to complete successfully.");
 			goto error;
 		}
 	}
@@ -2573,7 +2615,7 @@ void warn_command_name_and_directory_clash(struct bt_config *cfg)
 
 	if (g_file_test(cfg->command_name,
 			G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
-		_bt_log_write_d(_BT_LOG_SRCLOC_FUNCTION, __FILE__, __LINE__,
+		bt_log_write_printf(__FILE__, __func__, __LINE__,
 				BT_LOG_WARNING, BT_LOG_TAG,
 				"The `%s` command was executed. "
 				"If you meant to convert a trace located in "
@@ -2616,8 +2658,8 @@ void print_error_causes(void)
 	 */
 	fputc('\n',  stderr);
 
-	error_str = format_bt_error(error, columns, bt_cli_log_level,
-		BT_COMMON_COLOR_WHEN_AUTO);
+	error_str = format_bt_error(error, columns,
+		(bt_logging_level) bt_cli_log_level, BT_COMMON_COLOR_WHEN_AUTO);
 	BT_ASSERT(error_str);
 
 	fprintf(stderr, "%s\n", error_str);
@@ -2632,7 +2674,8 @@ end:
 
 int main(int argc, const char **argv)
 {
-	int ret, retcode;
+	int retcode;
+	enum bt_config_cli_args_status cli_args_status;
 	enum bt_cmd_status cmd_status;
 	struct bt_config *cfg = NULL;
 
@@ -2644,41 +2687,38 @@ int main(int argc, const char **argv)
 	the_interrupter = bt_interrupter_create();
 	if (!the_interrupter) {
 		BT_CLI_LOGE_APPEND_CAUSE("Failed to create an interrupter object.");
-		retcode = 1;
+		retcode = EXIT_FAILURE;
 		goto end;
 	}
 
-	cfg = bt_config_cli_args_create_with_default(argc, argv, &retcode,
+	cli_args_status = bt_config_cli_args_create_with_default(argc, argv, &cfg,
 		the_interrupter);
-
-	if (retcode < 0) {
+	if (cli_args_status == BT_CONFIG_CLI_ARGS_STATUS_INFO_ONLY) {
 		/* Quit without errors; typically usage/version */
-		retcode = 0;
+		retcode = EXIT_SUCCESS;
 		BT_LOGI_STR("Quitting without errors.");
 		goto end;
 	}
 
-	if (retcode > 0) {
+	if (cli_args_status == BT_CONFIG_CLI_ARGS_STATUS_ERROR) {
+		retcode = EXIT_FAILURE;
 		BT_CLI_LOGE_APPEND_CAUSE(
 			"Command-line error: retcode=%d", retcode);
 		goto end;
 	}
 
-	if (!cfg) {
-		BT_CLI_LOGE_APPEND_CAUSE(
-			"Failed to create a valid Babeltrace CLI configuration.");
-		retcode = 1;
-		goto end;
-	}
+	BT_ASSERT(cli_args_status == BT_CONFIG_CLI_ARGS_STATUS_OK);
+	BT_ASSERT(cfg);
 
 	print_cfg(cfg);
 
 	if (cfg->command_needs_plugins) {
-		ret = require_loaded_plugins(cfg->plugin_paths);
+		int ret = require_loaded_plugins(cfg->plugin_paths);
+
 		if (ret) {
 			BT_CLI_LOGE_APPEND_CAUSE(
 				"Failed to load plugins: ret=%d", ret);
-			retcode = 1;
+			retcode = EXIT_FAILURE;
 			goto end;
 		}
 	}
@@ -2716,13 +2756,13 @@ int main(int argc, const char **argv)
 
 	switch (cmd_status) {
 	case BT_CMD_STATUS_OK:
-		retcode = 0;
+		retcode = EXIT_SUCCESS;
 		break;
 	case BT_CMD_STATUS_ERROR:
-		retcode = 1;
+		retcode = EXIT_FAILURE;
 		break;
 	case BT_CMD_STATUS_INTERRUPTED:
-		retcode = 2;
+		retcode = EXIT_INTERRUPTED;
 		break;
 	default:
 		BT_LOGF("Invalid command status: cmd-status=%d", cmd_status);
@@ -2730,7 +2770,7 @@ int main(int argc, const char **argv)
 	}
 
 end:
-	if (retcode == 1) {
+	if (retcode == EXIT_FAILURE) {
 		print_error_causes();
 	}
 
