@@ -1,23 +1,7 @@
 /*
+ * SPDX-License-Identifier: MIT
+ *
  * Copyright (c) 2015-2018 Philippe Proulx <pproulx@efficios.com>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
  */
 
 #define BT_LOG_TAG "LIB/VALUE"
@@ -32,12 +16,19 @@
 #include "compat/compiler.h"
 #include "common/common.h"
 #include "compat/glib.h"
-#include "lib/assert-pre.h"
-#include "lib/assert-post.h"
+#include "lib/assert-cond.h"
 #include "lib/value.h"
 #include "common/assert.h"
 #include "func-status.h"
 
+#define BT_ASSERT_PRE_DEV_VALUE_HOT_FROM_FUNC(_func, _value)		\
+	BT_ASSERT_PRE_DEV_HOT_FROM_FUNC(_func, "value-object",		\
+		((struct bt_value *) (_value)), "Value object",		\
+		": %!+v", (_value))
+
+#define BT_ASSERT_PRE_DEV_VALUE_HOT(_value)				\
+	BT_ASSERT_PRE_DEV_VALUE_HOT_FROM_FUNC(__func__, (_value))
+
 #define BT_VALUE_TO_BOOL(_base) ((struct bt_value_bool *) (_base))
 #define BT_VALUE_TO_INTEGER(_base) ((struct bt_value_integer *) (_base))
 #define BT_VALUE_TO_REAL(_base) ((struct bt_value_real *) (_base))
@@ -45,28 +36,6 @@
 #define BT_VALUE_TO_ARRAY(_base) ((struct bt_value_array *) (_base))
 #define BT_VALUE_TO_MAP(_base) ((struct bt_value_map *) (_base))
 
-#define _BT_ASSERT_PRE_VALUE_IS_TYPE_COND(_value, _type)		\
-	(((struct bt_value *) (_value))->type == (_type))
-
-#define _BT_ASSERT_PRE_VALUE_IS_TYPE_FMT				\
-	"Value has the wrong type ID: expected-type=%s, %![value-]+v"
-
-#define BT_ASSERT_PRE_VALUE_IS_TYPE(_value, _type)			\
-	BT_ASSERT_PRE(							\
-		_BT_ASSERT_PRE_VALUE_IS_TYPE_COND((_value), (_type)),	\
-		_BT_ASSERT_PRE_VALUE_IS_TYPE_FMT,			\
-		bt_common_value_type_string(_type), (_value))
-
-#define BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(_value, _type)			\
-	BT_ASSERT_PRE_DEV(						\
-		_BT_ASSERT_PRE_VALUE_IS_TYPE_COND((_value), (_type)),	\
-		_BT_ASSERT_PRE_VALUE_IS_TYPE_FMT,			\
-		bt_common_value_type_string(_type), (_value))
-
-#define BT_ASSERT_PRE_DEV_VALUE_HOT(_value, _name)			\
-	BT_ASSERT_PRE_DEV_HOT(((struct bt_value *) (_value)), (_name),	\
-		": %!+v", (_value))
-
 static
 void bt_value_null_instance_release_func(struct bt_object *obj)
 {
@@ -87,6 +56,7 @@ struct bt_value bt_value_null_instance = {
 	.frozen = BT_TRUE,
 };
 
+BT_EXPORT
 struct bt_value *const bt_value_null = &bt_value_null_instance;
 
 static
@@ -297,8 +267,9 @@ struct bt_value *(* const copy_funcs[])(const struct bt_value *) = {
 };
 
 static
-bt_bool bt_value_null_is_equal(const struct bt_value *object_a,
-		const struct bt_value *object_b)
+bt_bool bt_value_null_is_equal(
+		const struct bt_value *object_a __attribute__((unused)),
+		const struct bt_value *object_b __attribute__((unused)))
 {
 	/*
 	 * Always BT_TRUE since bt_value_is_equal() already checks if both
@@ -480,7 +451,7 @@ bt_bool (* const is_equal_funcs[])(const struct bt_value *,
 };
 
 static
-void bt_value_null_freeze(struct bt_value *object)
+void bt_value_null_freeze(struct bt_value *object __attribute__((unused)))
 {
 }
 
@@ -552,7 +523,6 @@ void bt_value_destroy(struct bt_object *obj)
 	g_free(value);
 }
 
-BT_HIDDEN
 void _bt_value_freeze(const struct bt_value *c_object)
 {
 	const struct bt_value *object = (void *) c_object;
@@ -570,9 +540,10 @@ end:
 	return;
 }
 
+BT_EXPORT
 enum bt_value_type bt_value_get_type(const struct bt_value *object)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(object, "Value object");
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(object);
 	return object->type;
 }
 
@@ -587,6 +558,7 @@ struct bt_value bt_value_create_base(enum bt_value_type type)
 	return value;
 }
 
+BT_EXPORT
 struct bt_value *bt_value_bool_create_init(bt_bool val)
 {
 	struct bt_value_bool *bool_obj;
@@ -609,6 +581,7 @@ end:
 	return (void *) bool_obj;
 }
 
+BT_EXPORT
 struct bt_value *bt_value_bool_create(void)
 {
 	BT_ASSERT_PRE_NO_ERROR();
@@ -650,6 +623,7 @@ end:
 	return (void *) integer_obj;
 }
 
+BT_EXPORT
 struct bt_value *bt_value_integer_unsigned_create_init(uint64_t val)
 {
 	BT_ASSERT_PRE_NO_ERROR();
@@ -658,6 +632,7 @@ struct bt_value *bt_value_integer_unsigned_create_init(uint64_t val)
 		val);
 }
 
+BT_EXPORT
 struct bt_value *bt_value_integer_unsigned_create(void)
 {
 	BT_ASSERT_PRE_NO_ERROR();
@@ -665,6 +640,7 @@ struct bt_value *bt_value_integer_unsigned_create(void)
 	return bt_value_integer_unsigned_create_init(0);
 }
 
+BT_EXPORT
 struct bt_value *bt_value_integer_signed_create_init(int64_t val)
 {
 	BT_ASSERT_PRE_NO_ERROR();
@@ -673,6 +649,7 @@ struct bt_value *bt_value_integer_signed_create_init(int64_t val)
 		(uint64_t) val);
 }
 
+BT_EXPORT
 struct bt_value *bt_value_integer_signed_create(void)
 {
 	BT_ASSERT_PRE_NO_ERROR();
@@ -680,6 +657,7 @@ struct bt_value *bt_value_integer_signed_create(void)
 	return bt_value_integer_signed_create_init(0);
 }
 
+BT_EXPORT
 struct bt_value *bt_value_real_create_init(double val)
 {
 	struct bt_value_real *real_obj;
@@ -703,6 +681,7 @@ end:
 	return (void *) real_obj;
 }
 
+BT_EXPORT
 struct bt_value *bt_value_real_create(void)
 {
 	BT_ASSERT_PRE_NO_ERROR();
@@ -710,12 +689,13 @@ struct bt_value *bt_value_real_create(void)
 	return bt_value_real_create_init(0.);
 }
 
+BT_EXPORT
 struct bt_value *bt_value_string_create_init(const char *val)
 {
 	struct bt_value_string *string_obj = NULL;
 
 	BT_ASSERT_PRE_NO_ERROR();
-	BT_ASSERT_PRE_NON_NULL(val, "Value");
+	BT_ASSERT_PRE_NON_NULL("raw-value", val, "Raw value");
 
 	BT_LOGD("Creating string value object: val-len=%zu", strlen(val));
 	string_obj = g_new0(struct bt_value_string, 1);
@@ -742,6 +722,7 @@ end:
 	return (void *) string_obj;
 }
 
+BT_EXPORT
 struct bt_value *bt_value_string_create(void)
 {
 	BT_ASSERT_PRE_NO_ERROR();
@@ -749,6 +730,7 @@ struct bt_value *bt_value_string_create(void)
 	return bt_value_string_create_init("");
 }
 
+BT_EXPORT
 struct bt_value *bt_value_array_create(void)
 {
 	struct bt_value_array *array_obj;
@@ -780,6 +762,7 @@ end:
 	return (void *) array_obj;
 }
 
+BT_EXPORT
 struct bt_value *bt_value_map_create(void)
 {
 	struct bt_value_map *map_obj;
@@ -810,122 +793,134 @@ end:
 	return (void *) map_obj;
 }
 
+BT_EXPORT
 bt_bool bt_value_bool_get(const struct bt_value *bool_obj)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(bool_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(bool_obj, BT_VALUE_TYPE_BOOL);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(bool_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_BOOL(bool_obj);
 	return BT_VALUE_TO_BOOL(bool_obj)->value;
 }
 
+BT_EXPORT
 void bt_value_bool_set(struct bt_value *bool_obj, bt_bool val)
 {
-	BT_ASSERT_PRE_NON_NULL(bool_obj, "Value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(bool_obj, BT_VALUE_TYPE_BOOL);
-	BT_ASSERT_PRE_DEV_VALUE_HOT(bool_obj, "Value object");
+	BT_ASSERT_PRE_VALUE_NON_NULL(bool_obj);
+	BT_ASSERT_PRE_VALUE_IS_BOOL(bool_obj);
 	BT_VALUE_TO_BOOL(bool_obj)->value = val;
 	BT_LOGT("Set boolean value's raw value: value-addr=%p, value=%d",
 		bool_obj, val);
 }
 
+BT_EXPORT
 uint64_t bt_value_integer_unsigned_get(const struct bt_value *integer_obj)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(integer_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(integer_obj,
-		BT_VALUE_TYPE_UNSIGNED_INTEGER);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(integer_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_UNSIGNED_INT(integer_obj);
 	return BT_VALUE_TO_INTEGER(integer_obj)->value.u;
 }
 
+BT_EXPORT
 int64_t bt_value_integer_signed_get(const struct bt_value *integer_obj)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(integer_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(integer_obj,
-		BT_VALUE_TYPE_SIGNED_INTEGER);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(integer_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_SIGNED_INT(integer_obj);
 	return BT_VALUE_TO_INTEGER(integer_obj)->value.i;
 }
 
 static inline
-void bt_value_integer_set(struct bt_value *integer_obj,
-		enum bt_value_type expected_type, uint64_t uval)
+void set_integer_value(struct bt_value *integer_obj,
+		uint64_t uval,
+		const char *api_func)
 {
-	BT_ASSERT_PRE_NON_NULL(integer_obj, "Value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(integer_obj, expected_type);
-	BT_ASSERT_PRE_DEV_VALUE_HOT(integer_obj, "Value object");
+	BT_ASSERT_PRE_DEV_VALUE_HOT_FROM_FUNC(api_func, integer_obj);
 	BT_VALUE_TO_INTEGER(integer_obj)->value.u = uval;
 }
 
+BT_EXPORT
 void bt_value_integer_unsigned_set(struct bt_value *integer_obj,
 		uint64_t val)
 {
-	bt_value_integer_set(integer_obj, BT_VALUE_TYPE_UNSIGNED_INTEGER, val);
+	BT_ASSERT_PRE_VALUE_NON_NULL(integer_obj);
+	BT_ASSERT_PRE_VALUE_IS_UNSIGNED_INT(integer_obj);
+	set_integer_value(integer_obj, val, __func__);
 	BT_LOGT("Set unsigned integer value's raw value: "
 		"value-addr=%p, value=%" PRIu64, integer_obj, val);
 }
 
+BT_EXPORT
 void bt_value_integer_signed_set(struct bt_value *integer_obj,
 		int64_t val)
 {
-	bt_value_integer_set(integer_obj, BT_VALUE_TYPE_SIGNED_INTEGER,
-		(uint64_t) val);
+	BT_ASSERT_PRE_VALUE_NON_NULL(integer_obj);
+	BT_ASSERT_PRE_VALUE_IS_SIGNED_INT(integer_obj);
+	set_integer_value(integer_obj, (uint64_t) val, __func__);
 	BT_LOGT("Set signed integer value's raw value: "
 		"value-addr=%p, value=%" PRId64, integer_obj, val);
 }
 
+BT_EXPORT
 double bt_value_real_get(const struct bt_value *real_obj)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(real_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(real_obj, BT_VALUE_TYPE_REAL);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(real_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_REAL(real_obj);
 	return BT_VALUE_TO_REAL(real_obj)->value;
 }
 
+BT_EXPORT
 void bt_value_real_set(struct bt_value *real_obj, double val)
 {
-	BT_ASSERT_PRE_NON_NULL(real_obj, "Value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(real_obj, BT_VALUE_TYPE_REAL);
-	BT_ASSERT_PRE_DEV_VALUE_HOT(real_obj, "Value object");
+	BT_ASSERT_PRE_VALUE_NON_NULL(real_obj);
+	BT_ASSERT_PRE_VALUE_IS_REAL(real_obj);
+	BT_ASSERT_PRE_DEV_VALUE_HOT(real_obj);
 	BT_VALUE_TO_REAL(real_obj)->value = val;
 	BT_LOGT("Set real number value's raw value: value-addr=%p, value=%f",
 		real_obj, val);
 }
 
+BT_EXPORT
 const char *bt_value_string_get(const struct bt_value *string_obj)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(string_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(string_obj, BT_VALUE_TYPE_STRING);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(string_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_STRING(string_obj);
 	return BT_VALUE_TO_STRING(string_obj)->gstr->str;
 }
 
+BT_EXPORT
 enum bt_value_string_set_status bt_value_string_set(
 		struct bt_value *string_obj, const char *val)
 {
 	BT_ASSERT_PRE_NO_ERROR();
-	BT_ASSERT_PRE_NON_NULL(string_obj, "Value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(string_obj, BT_VALUE_TYPE_STRING);
-	BT_ASSERT_PRE_DEV_VALUE_HOT(string_obj, "Value object");
+	BT_ASSERT_PRE_VALUE_NON_NULL(string_obj);
+	BT_ASSERT_PRE_VALUE_IS_STRING(string_obj);
+	BT_ASSERT_PRE_DEV_VALUE_HOT(string_obj);
 	g_string_assign(BT_VALUE_TO_STRING(string_obj)->gstr, val);
 	BT_LOGT("Set string value's raw value: value-addr=%p, raw-value-addr=%p",
 		string_obj, val);
 	return BT_FUNC_STATUS_OK;
 }
 
+BT_EXPORT
 uint64_t bt_value_array_get_length(const struct bt_value *array_obj)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(array_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(array_obj, BT_VALUE_TYPE_ARRAY);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(array_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_ARRAY(array_obj);
 	return (uint64_t) BT_VALUE_TO_ARRAY(array_obj)->garray->len;
 }
 
+BT_EXPORT
 struct bt_value *bt_value_array_borrow_element_by_index(
 		struct bt_value *array_obj, uint64_t index)
 {
 	struct bt_value_array *typed_array_obj =
 		BT_VALUE_TO_ARRAY(array_obj);
 
-	BT_ASSERT_PRE_DEV_NON_NULL(array_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(array_obj, BT_VALUE_TYPE_ARRAY);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(array_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_ARRAY(array_obj);
 	BT_ASSERT_PRE_DEV_VALID_INDEX(index, typed_array_obj->garray->len);
 	return g_ptr_array_index(typed_array_obj->garray, index);
 }
 
+BT_EXPORT
 const struct bt_value *bt_value_array_borrow_element_by_index_const(
 		const struct bt_value *array_obj,
 		uint64_t index)
@@ -934,18 +929,22 @@ const struct bt_value *bt_value_array_borrow_element_by_index_const(
 		(void *) array_obj, index);
 }
 
-enum bt_value_array_append_element_status bt_value_array_append_element(
+static
+enum bt_value_array_append_element_status append_array_element(
 		struct bt_value *array_obj,
-		struct bt_value *element_obj)
+		struct bt_value *element_obj, const char *api_func)
 {
 	struct bt_value_array *typed_array_obj =
 		BT_VALUE_TO_ARRAY(array_obj);
 
-	BT_ASSERT_PRE_NO_ERROR();
-	BT_ASSERT_PRE_NON_NULL(array_obj, "Array value object");
-	BT_ASSERT_PRE_NON_NULL(element_obj, "Element value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(array_obj, BT_VALUE_TYPE_ARRAY);
-	BT_ASSERT_PRE_DEV_VALUE_HOT(array_obj, "Array value object");
+	BT_ASSERT_PRE_NO_ERROR_FROM_FUNC(api_func);
+	BT_ASSERT_PRE_NON_NULL_FROM_FUNC(api_func, "array-value-object",
+		array_obj, "Array value object");
+	BT_ASSERT_PRE_NON_NULL_FROM_FUNC(api_func, "element-value-object",
+		element_obj, "Element value object");
+	BT_ASSERT_PRE_VALUE_HAS_TYPE_FROM_FUNC(api_func, "value-object",
+		array_obj, "array", BT_VALUE_TYPE_ARRAY);
+	BT_ASSERT_PRE_DEV_VALUE_HOT_FROM_FUNC(api_func, array_obj);
 	g_ptr_array_add(typed_array_obj->garray, element_obj);
 	bt_object_get_ref(element_obj);
 	BT_LOGT("Appended element to array value: array-value-addr=%p, "
@@ -954,6 +953,15 @@ enum bt_value_array_append_element_status bt_value_array_append_element(
 	return BT_FUNC_STATUS_OK;
 }
 
+BT_EXPORT
+enum bt_value_array_append_element_status bt_value_array_append_element(
+		struct bt_value *array_obj,
+		struct bt_value *element_obj)
+{
+	return append_array_element(array_obj, element_obj, __func__);
+}
+
+BT_EXPORT
 enum bt_value_array_append_element_status
 bt_value_array_append_bool_element(struct bt_value *array_obj, bt_bool val)
 {
@@ -963,12 +971,13 @@ bt_value_array_append_bool_element(struct bt_value *array_obj, bt_bool val)
 	BT_ASSERT_PRE_NO_ERROR();
 
 	bool_obj = bt_value_bool_create_init(val);
-	ret = bt_value_array_append_element(array_obj,
-		(void *) bool_obj);
+	ret = append_array_element(array_obj,
+		(void *) bool_obj, __func__);
 	bt_object_put_ref(bool_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_array_append_element_status
 bt_value_array_append_unsigned_integer_element(struct bt_value *array_obj,
 		uint64_t val)
@@ -979,12 +988,13 @@ bt_value_array_append_unsigned_integer_element(struct bt_value *array_obj,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	integer_obj = bt_value_integer_unsigned_create_init(val);
-	ret = bt_value_array_append_element(array_obj,
-		(void *) integer_obj);
+	ret = append_array_element(array_obj,
+		(void *) integer_obj, __func__);
 	bt_object_put_ref(integer_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_array_append_element_status
 bt_value_array_append_signed_integer_element(struct bt_value *array_obj,
 		int64_t val)
@@ -995,12 +1005,13 @@ bt_value_array_append_signed_integer_element(struct bt_value *array_obj,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	integer_obj = bt_value_integer_signed_create_init(val);
-	ret = bt_value_array_append_element(array_obj,
-		(void *) integer_obj);
+	ret = append_array_element(array_obj,
+		(void *) integer_obj, __func__);
 	bt_object_put_ref(integer_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_array_append_element_status
 bt_value_array_append_real_element(struct bt_value *array_obj, double val)
 {
@@ -1010,12 +1021,13 @@ bt_value_array_append_real_element(struct bt_value *array_obj, double val)
 	BT_ASSERT_PRE_NO_ERROR();
 
 	real_obj = bt_value_real_create_init(val);
-	ret = bt_value_array_append_element(array_obj,
-		(void *) real_obj);
+	ret = append_array_element(array_obj,
+		(void *) real_obj, __func__);
 	bt_object_put_ref(real_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_array_append_element_status
 bt_value_array_append_string_element(struct bt_value *array_obj,
 		const char *val)
@@ -1026,12 +1038,13 @@ bt_value_array_append_string_element(struct bt_value *array_obj,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	string_obj = bt_value_string_create_init(val);
-	ret = bt_value_array_append_element(array_obj,
-		(void *) string_obj);
+	ret = append_array_element(array_obj,
+		(void *) string_obj, __func__);
 	bt_object_put_ref(string_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_array_append_element_status
 bt_value_array_append_empty_array_element(struct bt_value *array_obj,
 		struct bt_value **element_obj)
@@ -1042,8 +1055,8 @@ bt_value_array_append_empty_array_element(struct bt_value *array_obj,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	empty_array_obj = bt_value_array_create();
-	ret = bt_value_array_append_element(array_obj,
-		(void *) empty_array_obj);
+	ret = append_array_element(array_obj,
+		(void *) empty_array_obj, __func__);
 
 	if (element_obj) {
 		*element_obj = empty_array_obj;
@@ -1053,6 +1066,7 @@ bt_value_array_append_empty_array_element(struct bt_value *array_obj,
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_array_append_element_status
 bt_value_array_append_empty_map_element(struct bt_value *array_obj,
 		struct bt_value **element_obj)
@@ -1063,8 +1077,8 @@ bt_value_array_append_empty_map_element(struct bt_value *array_obj,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	map_obj = bt_value_map_create();
-	ret = bt_value_array_append_element(array_obj,
-		(void *) map_obj);
+	ret = append_array_element(array_obj,
+		(void *) map_obj, __func__);
 
 	if (element_obj) {
 		*element_obj = map_obj;
@@ -1074,6 +1088,7 @@ bt_value_array_append_empty_map_element(struct bt_value *array_obj,
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_array_set_element_by_index_status
 bt_value_array_set_element_by_index(struct bt_value *array_obj, uint64_t index,
 		struct bt_value *element_obj)
@@ -1082,10 +1097,12 @@ bt_value_array_set_element_by_index(struct bt_value *array_obj, uint64_t index,
 		BT_VALUE_TO_ARRAY(array_obj);
 
 	BT_ASSERT_PRE_NO_ERROR();
-	BT_ASSERT_PRE_NON_NULL(array_obj, "Array value object");
-	BT_ASSERT_PRE_NON_NULL(element_obj, "Element value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(array_obj, BT_VALUE_TYPE_ARRAY);
-	BT_ASSERT_PRE_DEV_VALUE_HOT(array_obj, "Array value object");
+	BT_ASSERT_PRE_NON_NULL("array-value-object", array_obj,
+		"Array value object");
+	BT_ASSERT_PRE_NON_NULL("element-value-object", element_obj,
+		"Element value object");
+	BT_ASSERT_PRE_VALUE_IS_ARRAY(array_obj);
+	BT_ASSERT_PRE_DEV_VALUE_HOT(array_obj);
 	BT_ASSERT_PRE_VALID_INDEX(index, typed_array_obj->garray->len);
 	bt_object_put_ref(g_ptr_array_index(typed_array_obj->garray, index));
 	g_ptr_array_index(typed_array_obj->garray, index) = element_obj;
@@ -1096,48 +1113,56 @@ bt_value_array_set_element_by_index(struct bt_value *array_obj, uint64_t index,
 	return BT_FUNC_STATUS_OK;
 }
 
+BT_EXPORT
 uint64_t bt_value_map_get_size(const struct bt_value *map_obj)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(map_obj, "Value object");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(map_obj, BT_VALUE_TYPE_MAP);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(map_obj);
+	BT_ASSERT_PRE_DEV_VALUE_IS_MAP(map_obj);
 	return (uint64_t) g_hash_table_size(BT_VALUE_TO_MAP(map_obj)->ght);
 }
 
+BT_EXPORT
 struct bt_value *bt_value_map_borrow_entry_value(struct bt_value *map_obj,
 		const char *key)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(map_obj, "Value object");
-	BT_ASSERT_PRE_DEV_NON_NULL(key, "Key");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(map_obj, BT_VALUE_TYPE_MAP);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(map_obj);
+	BT_ASSERT_PRE_DEV_KEY_NON_NULL(key);
+	BT_ASSERT_PRE_DEV_VALUE_IS_MAP(map_obj);
 	return g_hash_table_lookup(BT_VALUE_TO_MAP(map_obj)->ght,
 		GUINT_TO_POINTER(g_quark_from_string(key)));
 }
 
+BT_EXPORT
 const struct bt_value *bt_value_map_borrow_entry_value_const(
 		const struct bt_value *map_obj, const char *key)
 {
 	return bt_value_map_borrow_entry_value((void *) map_obj, key);
 }
 
+BT_EXPORT
 bt_bool bt_value_map_has_entry(const struct bt_value *map_obj, const char *key)
 {
-	BT_ASSERT_PRE_DEV_NON_NULL(map_obj, "Value object");
-	BT_ASSERT_PRE_DEV_NON_NULL(key, "Key");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(map_obj, BT_VALUE_TYPE_MAP);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL(map_obj);
+	BT_ASSERT_PRE_DEV_KEY_NON_NULL(key);
+	BT_ASSERT_PRE_DEV_VALUE_IS_MAP(map_obj);
 	return bt_g_hash_table_contains(BT_VALUE_TO_MAP(map_obj)->ght,
 		GUINT_TO_POINTER(g_quark_from_string(key)));
 }
 
-enum bt_value_map_insert_entry_status bt_value_map_insert_entry(
+static
+enum bt_value_map_insert_entry_status insert_map_value_entry(
 		struct bt_value *map_obj, const char *key,
-		struct bt_value *element_obj)
+		struct bt_value *element_obj, const char *api_func)
 {
-	BT_ASSERT_PRE_NO_ERROR();
-	BT_ASSERT_PRE_NON_NULL(map_obj, "Map value object");
-	BT_ASSERT_PRE_NON_NULL(key, "Key");
-	BT_ASSERT_PRE_NON_NULL(element_obj, "Element value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(map_obj, BT_VALUE_TYPE_MAP);
-	BT_ASSERT_PRE_DEV_VALUE_HOT(map_obj, "Map value object");
+	BT_ASSERT_PRE_NO_ERROR_FROM_FUNC(api_func);
+	BT_ASSERT_PRE_NON_NULL_FROM_FUNC(api_func, "map-value-object",
+		map_obj, "Map value object");
+	BT_ASSERT_PRE_KEY_NON_NULL_FROM_FUNC(api_func, key);
+	BT_ASSERT_PRE_NON_NULL_FROM_FUNC(api_func,
+		"element-value-object", element_obj, "Element value object");
+	BT_ASSERT_PRE_VALUE_HAS_TYPE_FROM_FUNC(api_func, "value-object",
+		map_obj, "map", BT_VALUE_TYPE_MAP);
+	BT_ASSERT_PRE_DEV_VALUE_HOT_FROM_FUNC(api_func, map_obj);
 	g_hash_table_insert(BT_VALUE_TO_MAP(map_obj)->ght,
 		GUINT_TO_POINTER(g_quark_from_string(key)), element_obj);
 	bt_object_get_ref(element_obj);
@@ -1147,6 +1172,15 @@ enum bt_value_map_insert_entry_status bt_value_map_insert_entry(
 	return BT_FUNC_STATUS_OK;
 }
 
+BT_EXPORT
+enum bt_value_map_insert_entry_status bt_value_map_insert_entry(
+		struct bt_value *map_obj, const char *key,
+		struct bt_value *element_obj)
+{
+	return insert_map_value_entry(map_obj, key, element_obj, __func__);
+}
+
+BT_EXPORT
 enum bt_value_map_insert_entry_status bt_value_map_insert_bool_entry(
 		struct bt_value *map_obj, const char *key, bt_bool val)
 {
@@ -1156,12 +1190,13 @@ enum bt_value_map_insert_entry_status bt_value_map_insert_bool_entry(
 	BT_ASSERT_PRE_NO_ERROR();
 
 	bool_obj = bt_value_bool_create_init(val);
-	ret = bt_value_map_insert_entry(map_obj, key,
-		(void *) bool_obj);
+	ret = insert_map_value_entry(map_obj, key,
+		(void *) bool_obj, __func__);
 	bt_object_put_ref(bool_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_map_insert_entry_status
 bt_value_map_insert_unsigned_integer_entry(struct bt_value *map_obj,
 		const char *key, uint64_t val)
@@ -1172,12 +1207,13 @@ bt_value_map_insert_unsigned_integer_entry(struct bt_value *map_obj,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	integer_obj = bt_value_integer_unsigned_create_init(val);
-	ret = bt_value_map_insert_entry(map_obj, key,
-		(void *) integer_obj);
+	ret = insert_map_value_entry(map_obj, key,
+		(void *) integer_obj, __func__);
 	bt_object_put_ref(integer_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_map_insert_entry_status
 bt_value_map_insert_signed_integer_entry(struct bt_value *map_obj,
 		const char *key, int64_t val)
@@ -1188,12 +1224,13 @@ bt_value_map_insert_signed_integer_entry(struct bt_value *map_obj,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	integer_obj = bt_value_integer_signed_create_init(val);
-	ret = bt_value_map_insert_entry(map_obj, key,
-		(void *) integer_obj);
+	ret = insert_map_value_entry(map_obj, key,
+		(void *) integer_obj, __func__);
 	bt_object_put_ref(integer_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_map_insert_entry_status bt_value_map_insert_real_entry(
 		struct bt_value *map_obj, const char *key, double val)
 {
@@ -1203,12 +1240,13 @@ enum bt_value_map_insert_entry_status bt_value_map_insert_real_entry(
 	BT_ASSERT_PRE_NO_ERROR();
 
 	real_obj = bt_value_real_create_init(val);
-	ret = bt_value_map_insert_entry(map_obj, key,
-		(void *) real_obj);
+	ret = insert_map_value_entry(map_obj, key,
+		(void *) real_obj, __func__);
 	bt_object_put_ref(real_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_map_insert_entry_status bt_value_map_insert_string_entry(
 		struct bt_value *map_obj, const char *key,
 		const char *val)
@@ -1219,12 +1257,13 @@ enum bt_value_map_insert_entry_status bt_value_map_insert_string_entry(
 	BT_ASSERT_PRE_NO_ERROR();
 
 	string_obj = bt_value_string_create_init(val);
-	ret = bt_value_map_insert_entry(map_obj, key,
-		(void *) string_obj);
+	ret = insert_map_value_entry(map_obj, key,
+		(void *) string_obj, __func__);
 	bt_object_put_ref(string_obj);
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_map_insert_entry_status
 bt_value_map_insert_empty_array_entry(
 		struct bt_value *map_obj, const char *key,
@@ -1236,8 +1275,8 @@ bt_value_map_insert_empty_array_entry(
 	BT_ASSERT_PRE_NO_ERROR();
 
 	array_obj = bt_value_array_create();
-	ret = bt_value_map_insert_entry(map_obj, key,
-		(void *) array_obj);
+	ret = insert_map_value_entry(map_obj, key,
+		(void *) array_obj, __func__);
 
 	if (entry_obj) {
 		*entry_obj = array_obj;
@@ -1247,6 +1286,7 @@ bt_value_map_insert_empty_array_entry(
 	return ret;
 }
 
+BT_EXPORT
 enum bt_value_map_insert_entry_status
 bt_value_map_insert_empty_map_entry(struct bt_value *map_obj, const char *key,
 		bt_value **entry_obj)
@@ -1257,8 +1297,8 @@ bt_value_map_insert_empty_map_entry(struct bt_value *map_obj, const char *key,
 	BT_ASSERT_PRE_NO_ERROR();
 
 	empty_map_obj = bt_value_map_create();
-	ret = bt_value_map_insert_entry(map_obj, key,
-		(void *) empty_map_obj);
+	ret = insert_map_value_entry(map_obj, key,
+		(void *) empty_map_obj, __func__);
 
 	if (entry_obj) {
 		*entry_obj = empty_map_obj;
@@ -1268,27 +1308,31 @@ bt_value_map_insert_empty_map_entry(struct bt_value *map_obj, const char *key,
 	return ret;
 }
 
-enum bt_value_map_foreach_entry_status bt_value_map_foreach_entry(
+static
+enum bt_value_map_foreach_entry_status foreach_map_entry(
 		struct bt_value *map_obj, bt_value_map_foreach_entry_func func,
-		void *data)
+		void *data, const char *api_func,
+		const char *user_func_name)
 {
 	int status = BT_FUNC_STATUS_OK;
 	gpointer key, element_obj;
 	GHashTableIter iter;
 	struct bt_value_map *typed_map_obj = BT_VALUE_TO_MAP(map_obj);
 
-	BT_ASSERT_PRE_NO_ERROR();
-
-	BT_ASSERT_PRE_DEV_NON_NULL(map_obj, "Value object");
-	BT_ASSERT_PRE_DEV_NON_NULL(func, "Callback");
-	BT_ASSERT_PRE_DEV_VALUE_IS_TYPE(map_obj, BT_VALUE_TYPE_MAP);
+	BT_ASSERT_PRE_NO_ERROR_FROM_FUNC(api_func);
+	BT_ASSERT_PRE_DEV_VALUE_NON_NULL_FROM_FUNC(api_func, map_obj);
+	BT_ASSERT_PRE_DEV_NON_NULL_FROM_FUNC(api_func, "user-function",
+		func, "User function");
+	BT_ASSERT_PRE_VALUE_HAS_TYPE_FROM_FUNC(api_func, "value-object",
+		map_obj, "map", BT_VALUE_TYPE_MAP);
 	g_hash_table_iter_init(&iter, typed_map_obj->ght);
 
 	while (g_hash_table_iter_next(&iter, &key, &element_obj)) {
 		const char *key_str = g_quark_to_string(GPOINTER_TO_UINT(key));
 
 		status = func(key_str, element_obj, data);
-		BT_ASSERT_POST_NO_ERROR_IF_NO_ERROR_STATUS(status);
+		BT_ASSERT_POST_NO_ERROR_IF_NO_ERROR_STATUS(user_func_name,
+			status);
 		if (status != BT_FUNC_STATUS_OK) {
 			if (status < 0) {
 				BT_LIB_LOGE_APPEND_CAUSE(
@@ -1323,14 +1367,23 @@ enum bt_value_map_foreach_entry_status bt_value_map_foreach_entry(
 	return status;
 }
 
+BT_EXPORT
+enum bt_value_map_foreach_entry_status bt_value_map_foreach_entry(
+		struct bt_value *map_obj, bt_value_map_foreach_entry_func func,
+		void *data)
+{
+	return foreach_map_entry(map_obj, func, data, __func__,
+		"bt_value_map_foreach_entry_func");
+}
+
+BT_EXPORT
 enum bt_value_map_foreach_entry_const_status bt_value_map_foreach_entry_const(
 		const struct bt_value *map_obj,
 		bt_value_map_foreach_entry_const_func func, void *data)
 {
-	BT_ASSERT_PRE_NO_ERROR();
-
-	return (int) bt_value_map_foreach_entry((void *) map_obj,
-		(bt_value_map_foreach_entry_func) func, data);
+	return (int) foreach_map_entry((void *) map_obj,
+		(bt_value_map_foreach_entry_func) func, data, __func__,
+		"bt_value_map_foreach_entry_const_func");
 }
 
 struct extend_map_element_data {
@@ -1379,6 +1432,7 @@ end:
 	return status;
 }
 
+BT_EXPORT
 enum bt_value_map_extend_status bt_value_map_extend(
 		struct bt_value *base_map_obj,
 		const struct bt_value *extension_obj)
@@ -1389,11 +1443,15 @@ enum bt_value_map_extend_status bt_value_map_extend(
 	};
 
 	BT_ASSERT_PRE_NO_ERROR();
-	BT_ASSERT_PRE_NON_NULL(base_map_obj, "Base value object");
-	BT_ASSERT_PRE_DEV_VALUE_HOT(base_map_obj, "Base value object");
-	BT_ASSERT_PRE_NON_NULL(extension_obj, "Extension value object");
-	BT_ASSERT_PRE_VALUE_IS_TYPE(base_map_obj, BT_VALUE_TYPE_MAP);
-	BT_ASSERT_PRE_VALUE_IS_TYPE(extension_obj, BT_VALUE_TYPE_MAP);
+	BT_ASSERT_PRE_NON_NULL("base-value-object", base_map_obj,
+		"Base value object");
+	BT_ASSERT_PRE_DEV_VALUE_HOT(base_map_obj);
+	BT_ASSERT_PRE_NON_NULL("extension-value-object", extension_obj,
+		"Extension value object");
+	BT_ASSERT_PRE_VALUE_HAS_TYPE("base-value-object", base_map_obj,
+		"map", BT_VALUE_TYPE_MAP);
+	BT_ASSERT_PRE_VALUE_HAS_TYPE("extension-value-object", extension_obj,
+		"map", BT_VALUE_TYPE_MAP);
 	BT_LOGD("Extending map value: base-value-addr=%p, extension-value-addr=%p",
 		base_map_obj, extension_obj);
 
@@ -1414,14 +1472,16 @@ enum bt_value_map_extend_status bt_value_map_extend(
 	return status;
 }
 
+BT_EXPORT
 enum bt_value_copy_status bt_value_copy(const struct bt_value *object,
 		struct bt_value **copy_obj)
 {
 	enum bt_value_copy_status status = BT_FUNC_STATUS_OK;
 
 	BT_ASSERT_PRE_NO_ERROR();
-	BT_ASSERT_PRE_NON_NULL(object, "Value object");
-	BT_ASSERT_PRE_NON_NULL(copy_obj, "Value object copy (output)");
+	BT_ASSERT_PRE_VALUE_NON_NULL(object);
+	BT_ASSERT_PRE_NON_NULL("value-object-copy-output", copy_obj,
+		"Value object copy (output)");
 	BT_LOGD("Copying value object: addr=%p", object);
 	*copy_obj = copy_funcs[object->type](object);
 	if (*copy_obj) {
@@ -1436,13 +1496,16 @@ enum bt_value_copy_status bt_value_copy(const struct bt_value *object,
 	return status;
 }
 
+BT_EXPORT
 bt_bool bt_value_is_equal(const struct bt_value *object_a,
 	const struct bt_value *object_b)
 {
 	bt_bool ret = BT_FALSE;
 
-	BT_ASSERT_PRE_DEV_NON_NULL(object_a, "Value object A");
-	BT_ASSERT_PRE_DEV_NON_NULL(object_b, "Value object B");
+	BT_ASSERT_PRE_DEV_NON_NULL("value-object-a", object_a,
+		"Value object A");
+	BT_ASSERT_PRE_DEV_NON_NULL("value-object-b", object_b,
+		"Value object B");
 
 	if (object_a->type != object_b->type) {
 		BT_LOGT("Values are different: type mismatch: "
@@ -1460,11 +1523,13 @@ end:
 	return ret;
 }
 
+BT_EXPORT
 void bt_value_get_ref(const struct bt_value *value)
 {
 	bt_object_get_ref(value);
 }
 
+BT_EXPORT
 void bt_value_put_ref(const struct bt_value *value)
 {
 	bt_object_put_ref(value);
