@@ -11,9 +11,6 @@
 
 #include "lttng-live.hpp"
 
-enum lttng_live_iterator_status lttng_live_lazy_msg_init(struct lttng_live_session *session,
-                                                         bt2::SelfMessageIterator selfMsgIter);
-
 struct lttng_live_stream_iterator *
 lttng_live_stream_iterator_create(struct lttng_live_session *session, uint64_t ctf_trace_id,
                                   uint64_t stream_id);
