@@ -1,28 +1,17 @@
+# SPDX-License-Identifier: GPL-2.0-only
 #
 # Copyright (C) 2019 EfficiOS Inc.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; only version 2
-# of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-#
 
 import unittest
-from utils import run_in_component_init
-from bt2 import stream_class as bt2_stream_class
-from bt2 import trace_class as bt2_trace_class
+
+from bt2 import value as bt2_value
 from bt2 import clock_class as bt2_clock_class
 from bt2 import event_class as bt2_event_class
 from bt2 import field_class as bt2_field_class
+from bt2 import trace_class as bt2_trace_class
+from bt2 import stream_class as bt2_stream_class
+from utils import run_in_component_init, get_const_stream_beginning_message
 
 
 class StreamClassTestCase(unittest.TestCase):
@@ -32,7 +21,7 @@ class StreamClassTestCase(unittest.TestCase):
             cc = comp_self._create_clock_class()
             return tc, cc
 
-        self._tc, self._cc = run_in_component_init(f)
+        self._tc, self._cc = run_in_component_init(0, f)
         self._trace = self._tc()
 
     def test_create_default(self):
@@ -55,8 +44,8 @@ class StreamClassTestCase(unittest.TestCase):
         self.assertEqual(len(sc.user_attributes), 0)
 
     def test_create_name(self):
-        sc = self._tc.create_stream_class(name='bozo')
-        self.assertEqual(sc.name, 'bozo')
+        sc = self._tc.create_stream_class(name="bozo")
+        self.assertEqual(sc.name, "bozo")
 
     def test_create_invalid_name(self):
         with self.assertRaisesRegex(TypeError, "'int' is not a 'str' object"):
@@ -128,8 +117,14 @@ class StreamClassTestCase(unittest.TestCase):
         self.assertEqual(len(self._tc), 0)
 
     def test_create_user_attributes(self):
-        sc = self._tc.create_stream_class(user_attributes={'salut': 23})
-        self.assertEqual(sc.user_attributes, {'salut': 23})
+        sc = self._tc.create_stream_class(user_attributes={"salut": 23})
+        self.assertEqual(sc.user_attributes, {"salut": 23})
+        self.assertIs(type(sc.user_attributes), bt2_value.MapValue)
+
+    def test_const_user_attributes(self):
+        sc = get_const_stream_beginning_message().stream.cls
+        self.assertEqual(sc.user_attributes, {"a-stream-class-attribute": 1})
+        self.assertIs(type(sc.user_attributes), bt2_value._MapValueConst)
 
     def test_create_invalid_user_attributes(self):
         with self.assertRaisesRegex(
@@ -168,7 +163,7 @@ class StreamClassTestCase(unittest.TestCase):
 
     def test_automatic_stream_ids_wrong_type(self):
         with self.assertRaisesRegex(TypeError, "str' is not a 'bool' object"):
-            self._tc.create_stream_class(assigns_automatic_stream_id='True')
+            self._tc.create_stream_class(assigns_automatic_stream_id="True")
 
         self.assertEqual(len(self._tc), 0)
 
@@ -212,7 +207,7 @@ class StreamClassTestCase(unittest.TestCase):
 
     def test_automatic_event_class_ids_wrong_type(self):
         with self.assertRaisesRegex(TypeError, "'str' is not a 'bool' object"):
-            self._tc.create_stream_class(assigns_automatic_event_class_id='True')
+            self._tc.create_stream_class(assigns_automatic_event_class_id="True")
 
         self.assertEqual(len(self._tc), 0)
 
@@ -362,7 +357,7 @@ class StreamClassTestCase(unittest.TestCase):
     ):
         with self.assertRaisesRegex(
             ValueError,
-            'cannot have no default clock class, but have default clock snapshots for discarded event messages',
+            "cannot have no default clock class, but have default clock snapshots for discarded event messages",
         ):
             self._tc.create_stream_class(
                 supports_discarded_events=True,
@@ -438,7 +433,7 @@ class StreamClassTestCase(unittest.TestCase):
     ):
         with self.assertRaisesRegex(
             ValueError,
-            'cannot have no default clock class, but have default clock snapshots for discarded packet messages',
+            "cannot have no default clock class, but have default clock snapshots for discarded packet messages",
         ):
             self._tc.create_stream_class(
                 supports_packets=True,
@@ -471,12 +466,12 @@ class StreamClassTestCase(unittest.TestCase):
         sc, _, _ = self._create_stream_class_with_event_classes()
 
         with self.assertRaisesRegex(TypeError, "'str' is not an 'int' object"):
-            sc['event23']
+            sc["event23"]
 
     def test_getitem_wrong_key(self):
         sc, _, _ = self._create_stream_class_with_event_classes()
 
-        with self.assertRaisesRegex(KeyError, '19'):
+        with self.assertRaisesRegex(KeyError, "19"):
             sc[19]
 
     def test_len(self):
@@ -491,5 +486,5 @@ class StreamClassTestCase(unittest.TestCase):
         self.assertEqual(ec_ids, [17, 23])
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
