@@ -61,7 +61,16 @@ import quopri
 import struct
 import typing
 import functools
-from typing import Any, Set, Dict, List, Union, Pattern, Callable, NoReturn, Optional
+from typing import Any, Set, Dict, List, Union, Pattern, Callable, Optional
+
+# Python 3.6.2 introduced `typing.NoReturn`. Since Normand supports
+# Python 3.4, define `NoReturn` here if it's not available.
+if sys.version_info >= (3, 6, 2):
+    from typing import NoReturn
+else:
+
+    class NoReturn:
+        pass
 
 
 # Text location (line and column numbers).
@@ -109,7 +118,8 @@ class _ScalarItem(_Item):
     # Returns the size, in bytes, of this item.
     @property
     @abc.abstractmethod
-    def size(self) -> int: ...
+    def size(self) -> int:
+        ...
 
 
 # A repeatable item.
@@ -617,7 +627,7 @@ class ParseError(RuntimeError):
 
     def _add_msg(self, msg: str, text_loc: TextLocation):
         self._msgs.append(
-            ParseErrorMessage._create(
+            ParseErrorMessage._create(  # pyright: ignore[reportPrivateUsage]
                 msg, text_loc
             )
         )
@@ -632,12 +642,12 @@ class ParseError(RuntimeError):
 
 # Raises a parsing error, forwarding the parameters to the constructor.
 def _raise_error(msg: str, text_loc: TextLocation) -> NoReturn:
-    raise ParseError._create(msg, text_loc)
+    raise ParseError._create(msg, text_loc)  # pyright: ignore[reportPrivateUsage]
 
 
 # Adds a message to the parsing error `exc`.
 def _add_error_msg(exc: ParseError, msg: str, text_loc: TextLocation):
-    exc._add_msg(msg, text_loc)
+    exc._add_msg(msg, text_loc)  # pyright: ignore[reportPrivateUsage]
 
 
 # Appends a message to the parsing error `exc` and reraises it.
@@ -760,7 +770,7 @@ class _Parser:
     # Current text location.
     @property
     def _text_loc(self):
-        return TextLocation._create(
+        return TextLocation._create(  # pyright: ignore[reportPrivateUsage]
             self._line_no, self._col_no
         )
 
@@ -2104,7 +2114,8 @@ class _NodeVisitor(ast.NodeVisitor):
         self._parent_is_call = False
 
     @abc.abstractmethod
-    def _visit_name(self, name: str): ...
+    def _visit_name(self, name: str):
+        ...
 
 
 # Expression validator: validates that all the names within the
@@ -2605,7 +2616,7 @@ class _Gen:
             # Process the contained group
             init_data_size = len(self._data)
             parse_error_msg = (
-                ParseErrorMessage._create(
+                ParseErrorMessage._create(  # pyright: ignore[reportPrivateUsage]
                     parse_error_msg_text, item.text_loc
                 )
             )
@@ -2831,7 +2842,9 @@ def parse(
         init_offset,
         init_byte_order,
     )
-    return ParseResult._create(gen.data, gen.variables, gen.labels, gen.offset, gen.bo)
+    return ParseResult._create(  # pyright: ignore[reportPrivateUsage]
+        gen.data, gen.variables, gen.labels, gen.offset, gen.bo
+    )
 
 
 # Raises a command-line error with the message `msg`.
